@@ -1,10 +1,9 @@
 /* ============================================================
- * File  : adjustcurves.h
- * Author: Gilles Caulier <caulier dot gilles at free.fr>
- * Date  : 2004-12-01
+ * Authors: Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Date   : 2004-12-01
  * Description : image histogram adjust curves. 
  * 
- * Copyright 2004-2005 by Gilles Caulier
+ * Copyright 2004-2007 by Gilles Caulier
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -26,108 +25,107 @@
 
 #include <qcolor.h>
 
-// Local includes.
+// Digikam includes.
 
-#include "imagetabdialog.h"
+#include <digikamheaders.h>
+
+// Local includes.
 
 class QComboBox;
 class QPushButton;
-class QLabel;
 class QHButtonGroup;
-class QCheckBox;
-
-namespace Digikam
-{
-class ImageCurves;
-class ImageGuideWidget;
-class ColorGradientWidget;
-class CurvesWidget;
-}
 
 namespace DigikamAdjustCurvesImagesPlugin
 {
 
-class AdjustCurveDialog : public DigikamImagePlugins::ImageTabDialog
+class AdjustCurveDialog : public Digikam::ImageDlgBase
 {
     Q_OBJECT
 
 public:
 
-    AdjustCurveDialog(QWidget *parent, uint *imageData, uint width, uint height);
+    AdjustCurveDialog(QWidget *parent, QString title, QFrame* banner);
     ~AdjustCurveDialog();
 
-protected:
+private:
 
-    void closeEvent(QCloseEvent *e);
+    void readUserSettings();
+    void writeUserSettings();
+    void resetValues();
+    void finalRendering();
     
+private slots:
+
+    void slotUser2();
+    void slotUser3();
+    void slotEffect();
+    void slotResetCurrentChannel();
+    void slotChannelChanged(int channel);
+    void slotScaleChanged(int scale);
+    void slotCurveTypeChanged(int type);
+    void slotSpotColorChanged(const Digikam::DColor &color);
+    void slotColorSelectedFromTarget(const Digikam::DColor &color);
+    void slotPickerColorButtonActived();
+
 private:
     
     enum ColorPicker
     {
-    BlackTonal=0,
-    GrayTonal,
-    WhiteTonal
+        BlackTonal=0,
+        GrayTonal,
+        WhiteTonal
     };
 
     enum ColorChannel
     {
-    LuminosityChannel=0,
-    RedChannel,
-    GreenChannel,
-    BlueChannel,
-    AlphaChannel
+        LuminosityChannel=0,
+        RedChannel,
+        GreenChannel,
+        BlueChannel,
+        AlphaChannel
     };
     
     enum CurvesDrawingType
     {
-    SmoothDrawing=0,
-    FreeDrawing
+        SmoothDrawing=0,
+        FreeDrawing
     };
     
     enum HistogramScale
     {
-    Linear=0,
-    Logarithmic
+        Linear=0,
+        Logarithmic
     };
     
+    uchar                        *m_destinationPreviewData;
+
+    int                           m_histoSegments;
+    int                           m_currentPreviewMode;
+        
     QComboBox                    *m_channelCB;    
-    QComboBox                    *m_typeCB;  
-    
-    QLabel                       *m_labelPos;
     
     QPushButton                  *m_resetButton;
     QPushButton                  *m_pickBlack;
     QPushButton                  *m_pickGray;
     QPushButton                  *m_pickWhite;
+    QPushButton                  *m_curveFree;
+    QPushButton                  *m_curveSmooth;
     
-    QCheckBox                    *m_overExposureIndicatorBox;
-
     QHButtonGroup                *m_pickerColorButtonGroup;
     QHButtonGroup                *m_scaleBG;  
+    QHButtonGroup                *m_curveType;
     
     Digikam::CurvesWidget        *m_curvesWidget;
+
+    Digikam::HistogramWidget     *m_histogramWidget;
     
     Digikam::ColorGradientWidget *m_hGradient;
     Digikam::ColorGradientWidget *m_vGradient;
-            
-    Digikam::ImageGuideWidget    *m_previewOriginalWidget;
-    Digikam::ImageGuideWidget    *m_previewTargetWidget;
-    
+        
+    Digikam::ImageWidget         *m_previewWidget;
+
     Digikam::ImageCurves         *m_curves;
-
-private slots:
-
-    void slotDefault();
-    void slotUser2();
-    void slotUser3();
-    void slotEffect();
-    void slotOk();
-    void slotResetCurrentChannel();
-    void slotChannelChanged(int channel);
-    void slotScaleChanged(int scale);
-    void slotCurveTypeChanged(int type);
-    void slotPositionChanged(int x, int y);
-    void slotSpotColorChanged(const QColor &color, bool release);
+    Digikam::DImg                 m_originalImage;
 };
 
 }  // NameSpace DigikamAdjustCurvesImagesPlugin
