@@ -1,10 +1,9 @@
 /* ============================================================
- * File  : imageplugin_adjustcurves.h
- * Author: Gilles Caulier <caulier dot gilles at free.fr>
- * Date  : 2004-12-01
+ * Authors: Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Date   : 2004-12-01
  * Description : 
  * 
- * Copyright 2004-2005 by Gilles Caulier
+ * Copyright 2004-2007 by Gilles Caulier
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -29,7 +28,7 @@
 
 class KAction;
 
-class ImagePlugin_AdjustCurves : public Digikam::ImagePlugin
+class DIGIKAMIMAGEPLUGINS_EXPORT ImagePlugin_AdjustCurves : public Digikam::ImagePlugin
 {
     Q_OBJECT
     
