@@ -1,11 +1,10 @@
 /* ============================================================
- * File  : imageeffect_antivignetting.h
- * Author: Gilles Caulier <caulier dot gilles at free.fr>
- * Date  : 2004-12-25
+ * Authors: Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Date   : 2004-12-25
  * Description : a digiKam image plugin to reduce 
  *               vignetting on an image.
  * 
- * Copyright 2004-2005 by Gilles Caulier
+ * Copyright 2004-2007 by Gilles Caulier
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -23,12 +22,11 @@
 #ifndef IMAGEEFFECT_ANTIVIGNETTING_H
 #define IMAGEEFFECT_ANTIVIGNETTING_H
 
-// Local includes.
+// Digikam includes.
 
-#include "imageguidedialog.h"
+#include <digikamheaders.h>
 
 class QLabel;
-class QTabWidget;
 
 class KIntNumInput;
 class KDoubleNumInput;
@@ -36,35 +34,40 @@ class KDoubleNumInput;
 namespace DigikamAntiVignettingImagesPlugin
 {
 
-class ImageEffect_AntiVignetting : public DigikamImagePlugins::ImageGuideDialog
+class ImageEffect_AntiVignetting : public Digikam::ImageGuideDlg
 {
     Q_OBJECT
     
 public:
 
-    ImageEffect_AntiVignetting(QWidget *parent);
+    ImageEffect_AntiVignetting(QWidget *parent, QString title, QFrame* banner);
     ~ImageEffect_AntiVignetting();
 
+private slots:
+
+    void readUserSettings();
+
 private:
 
-    QLabel               *m_maskPreviewLabel;
+    void writeUserSettings();
+    void resetValues();     
+    void prepareEffect();
+    void prepareFinal();
+    void putPreviewData();
+    void putFinalData();
+    void renderingFinished();
+
+private:
+
+    QLabel          *m_maskPreviewLabel;
     
-    KIntNumInput         *m_brightnessInput;
-    KIntNumInput         *m_contrastInput;
-    KIntNumInput         *m_gammaInput;
+    KIntNumInput    *m_brightnessInput;
+    KIntNumInput    *m_contrastInput;
     
-    KDoubleNumInput      *m_densityInput;
-    KDoubleNumInput      *m_powerInput;
-    KDoubleNumInput      *m_radiusInput;
-    
-protected:
-    
-    void prepareEffect(void);
-    void prepareFinal(void);
-    void putPreviewData(void);
-    void putFinalData(void);
-    void resetValues(void);   
-    void renderingFinished(void);
+    KDoubleNumInput *m_gammaInput;
+    KDoubleNumInput *m_densityInput;
+    KDoubleNumInput *m_powerInput;
+    KDoubleNumInput *m_radiusInput;
 };
 
 }  // NameSpace DigikamAntiVignettingImagesPlugin
