@@ -1,10 +1,10 @@
 /* ============================================================
  * File  : imageplugin_antivignetting.cpp
- * Author: Gilles Caulier <caulier dot gilles at free.fr>
+ * Author: Gilles Caulier <caulier dot gilles at gmail dot com>
  * Date  : 2004-12-25
  * Description : 
  * 
- * Copyright 2004-2005 by Gilles Caulier
+ * Copyright 2004-2006 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -26,10 +26,10 @@
 #include <klibloader.h>
 #include <kaction.h>
 #include <kcursor.h>
-#include <kdebug.h>
 
 // Local includes.
 
+#include "bannerwidget.h"
 #include "imageeffect_antivignetting.h"
 #include "imageplugin_antivignetting.h"
 
@@ -45,7 +45,7 @@ ImagePlugin_AntiVignetting::ImagePlugin_AntiVignetting(QObject *parent, const ch
 
     setXMLFile("digikamimageplugin_antivignetting_ui.rc");                
     
-    kdDebug() << "ImagePlugin_AntiVignetting plugin loaded" << endl;
+    DDebug() << "ImagePlugin_AntiVignetting plugin loaded" << endl;
 }
 
 ImagePlugin_AntiVignetting::~ImagePlugin_AntiVignetting()
@@ -59,9 +59,12 @@ void ImagePlugin_AntiVignetting::setEnabledActions(bool enable)
 
 void ImagePlugin_AntiVignetting::slotAntiVignetting()
 {
-    DigikamAntiVignettingImagesPlugin::ImageEffect_AntiVignetting dlg(parentWidget());
+    QString title = i18n("Anti-Vignetting");
+    QFrame *headerFrame = new DigikamImagePlugins::BannerWidget(0, title);
+    DigikamAntiVignettingImagesPlugin::ImageEffect_AntiVignetting dlg(parentWidget(),
+                                title, headerFrame);
     dlg.exec();
+    delete headerFrame;
 }
 
-
 #include "imageplugin_antivignetting.moc"
