@@ -1,11 +1,11 @@
 /* ============================================================
  * File  : imageeffect_blowup.cpp
- * Author: Gilles Caulier <caulier dot gilles at free.fr>
+ * Author: Gilles Caulier <caulier dot gilles at gmail dot com>
  * Date  : 2005-04-07
  * Description : a digiKam image editor plugin to blowup
  *               a photograph
  *
- * Copyright 2005 by Gilles Caulier
+ * Copyright 2005 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -62,7 +62,6 @@
 #include <kmessagebox.h>
 #include <knuminput.h>
 #include <kglobalsettings.h>
-#include <kdebug.h>
 #include <kpassivepopup.h>
 
 // Digikam includes.
@@ -83,7 +82,7 @@ ImageEffect_BlowUp::ImageEffect_BlowUp(QWidget* parent)
                   : KDialogBase(Plain, i18n("Blowup Photograph"),
                                 Help|Default|User2|User3|Ok|Cancel, Ok,
                                 parent, 0, true, true,
-                                QString::null,
+                                QString(),
                                 i18n("&Save As..."),
                                 i18n("&Load...")),
                     m_parent(parent)
@@ -108,7 +107,7 @@ ImageEffect_BlowUp::ImageEffect_BlowUp(QWidget* parent)
                              "http://extragear.kde.org/apps/digikamimageplugins");
 
     m_about->addAuthor("Gilles Caulier", I18N_NOOP("Author and maintainer"),
-                       "caulier dot gilles at free.fr");
+                       "caulier dot gilles at gmail dot com");
 
     m_about->addAuthor("David Tschumperle", I18N_NOOP("CImg library"), 0,
                        "http://cimg.sourceforge.net");
@@ -139,7 +138,7 @@ ImageEffect_BlowUp::ImageEffect_BlowUp(QWidget* parent)
     m_mainTab->addTab( firstPage, i18n("New Size") );
 
     KURLLabel *cimgLogoLabel = new KURLLabel(firstPage);
-    cimgLogoLabel->setText(QString::null);
+    cimgLogoLabel->setText(QString());
     cimgLogoLabel->setURL("http://cimg.sourceforge.net");
     KGlobal::dirs()->addResourceType("cimg-logo", KGlobal::dirs()->kde_default("data") + "digikamimageplugins/data");
     QString directory = KGlobal::dirs()->findResourceDir("cimg-logo", "cimg-logo.png");
@@ -300,7 +299,7 @@ ImageEffect_BlowUp::ImageEffect_BlowUp(QWidget* parent)
 ImageEffect_BlowUp::~ImageEffect_BlowUp()
 {
     delete m_about;
-
+    
     if (m_cimgInterface)
        delete m_cimgInterface;
 }
@@ -339,30 +338,30 @@ void ImageEffect_BlowUp::slotDefault()
 void ImageEffect_BlowUp::slotAdjustRatioFromWidth(int w)
 {
     if ( m_preserveRatioBox->isChecked() )
-       {
+    {
        m_newHeight->blockSignals(true);
        m_newHeight->setValue( (int) (w / m_aspectRatio) );
        m_newHeight->blockSignals(false);
-       }
+    }
 }
 
 void ImageEffect_BlowUp::slotAdjustRatioFromHeight(int h)
 {
     if ( m_preserveRatioBox->isChecked() )
-       {
+    {
        m_newWidth->blockSignals(true);
        m_newWidth->setValue( (int)(m_aspectRatio * h) );
        m_newWidth->blockSignals(false);
-       }
+    }
 }
 
 void ImageEffect_BlowUp::slotCancel()
 {
     if (m_currentRenderingMode != NoneRendering)
-       {
+    {
        m_cimgInterface->stopComputation();
-       m_parent->setCursor( KCursor::arrowCursor() );
-       }
+       m_parent->unsetCursor();
+    }
 
     done(Cancel);
 }
@@ -380,10 +379,10 @@ void ImageEffect_BlowUp::processCImgURL(const QString& url)
 void ImageEffect_BlowUp::closeEvent(QCloseEvent *e)
 {
     if (m_currentRenderingMode != NoneRendering)
-       {
+    {
        m_cimgInterface->stopComputation();
-       m_parent->setCursor( KCursor::arrowCursor() );
-       }
+       m_parent->unsetCursor();
+    }
 
     e->accept();
 }
@@ -414,9 +413,10 @@ void ImageEffect_BlowUp::slotOk()
     m_progressBar->setValue(0);
 
     Digikam::ImageIface iface(0, 0);
-    QImage originalImage = QImage(iface.originalWidth(), iface.originalHeight(), 32);
-    uint *data = iface.getOriginalData();
-    memcpy( originalImage.bits(), data, originalImage.numBytes() );
+    uchar *data = iface.getOriginalImage();
+    Digikam::DImg originalImage = Digikam::DImg(iface.originalWidth(), iface.originalHeight(),
+                                  iface.originalSixteenBit(), iface.originalHasAlpha(), data);
+    delete [] data;
 
     if (m_cimgInterface)
        delete m_cimgInterface;
@@ -435,7 +435,6 @@ void ImageEffect_BlowUp::slotOk()
                                     false, false, true, NULL,
                                     m_newWidth->value(),
                                     m_newHeight->value(), 0, this);
-    delete [] data;
 }
 
 void ImageEffect_BlowUp::customEvent(QCustomEvent *event)
@@ -447,37 +446,39 @@ void ImageEffect_BlowUp::customEvent(QCustomEvent *event)
     if (!d) return;
 
     if (d->starting)           // Computation in progress !
-        {
+    {
         m_progressBar->setValue(d->progress);
-        }
+    }
     else
-        {
+    {
         if (d->success)        // Computation Completed !
-            {
+        {
             switch (m_currentRenderingMode)
-              {
-              case FinalRendering:
-                 {
-                 kdDebug() << "Final BlowUp completed..." << endl;
-                 Digikam::ImageIface iface(0, 0);
-                 QImage resizedImage = m_cimgInterface->getTargetImage();
-                 iface.putOriginalData(i18n("BlowUp"), (uint*)resizedImage.bits(),
-                                       resizedImage.width(), resizedImage.height());
-                 m_parent->setCursor( KCursor::arrowCursor() );
-                 accept();
-                 break;
-                 }
-              }
-            }
-        else                   // Computation Failed !
             {
-            switch (m_currentRenderingMode)
-                {
                 case FinalRendering:
+                {
+                    DDebug() << "Final BlowUp completed..." << endl;
+                    
+                    Digikam::ImageIface iface(0, 0);
+                    Digikam::DImg resizedImage = m_cimgInterface->getTargetImage();
+
+                    iface.putOriginalImage(i18n("BlowUp"), resizedImage.bits(),
+                                           resizedImage.width(), resizedImage.height());
+                    m_parent->unsetCursor();
+                    accept();
                     break;
                 }
             }
         }
+        else                   // Computation Failed !
+        {
+            switch (m_currentRenderingMode)
+            {
+                case FinalRendering:
+                    break;
+            }
+        }
+    }
 
     delete d;
 }
