@@ -1,6 +1,6 @@
 /* ============================================================
  * File  : imageplugin_blowup.h
- * Author: Gilles Caulier <caulier dot gilles at free.fr>
+ * Author: Gilles Caulier <caulier dot gilles at gmail dot com>
  * Date  : 2005-04-07
  * Description : 
  * 
@@ -29,7 +29,7 @@
 
 class KAction;
 
-class ImagePlugin_BlowUp : public Digikam::ImagePlugin
+class DIGIKAMIMAGEPLUGINS_EXPORT ImagePlugin_BlowUp : public Digikam::ImagePlugin
 {
     Q_OBJECT
     
