@@ -1,10 +1,9 @@
 /* ============================================================
- * File  : imageplugin_border.h
- * Author: Gilles Caulier <caulier dot gilles at free.fr>
- * Date  : 2005-01-20
+ * Authors: Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Date   : 2005-01-20
  * Description : 
  * 
- * Copyright 2005 by Gilles Caulier
+ * Copyright 2005-2007 by Gilles Caulier
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -27,7 +26,9 @@
 
 #include <digikamheaders.h>
 
-class ImagePlugin_Border : public Digikam::ImagePlugin
+class KAction;
+
+class DIGIKAMIMAGEPLUGINS_EXPORT ImagePlugin_Border : public Digikam::ImagePlugin
 {
     Q_OBJECT
     
@@ -36,11 +37,16 @@ public:
     ImagePlugin_Border(QObject *parent, const char* name,
                          const QStringList &args);
     ~ImagePlugin_Border();
+    
+    void setEnabledActions(bool enable);
 
 private slots:
 
     void slotBorder();
 
+private:
+
+    KAction *m_borderAction;
 };
     
 #endif /* IMAGEPLUGIN_BORDER_H */
