@@ -1,10 +1,10 @@
 /* ============================================================
- * File  : channelmixer.cpp
- * Author: Gilles Caulier <caulier dot gilles at free.fr>
- * Date  : 2005-02-26
+ * Authors: Gilles Caulier
+ * Date   : 2005-02-26
  * Description : 
  * 
- * Copyright 2005 by Gilles Caulier
+ * Copyright 2005-2007 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ *
  * Load and save mixer gains methods inspired from 
  * Gimp 2.2.3 and copyrighted 2002 by Martin Guldahl 
  * <mguldahl at xmission dot com>.
@@ -32,7 +32,6 @@
 
 // Qt includes.
 
-#include <qlayout.h>
 #include <qcolor.h>
 #include <qgroupbox.h>
 #include <qhgroupbox.h>
@@ -52,8 +51,8 @@
 
 // KDE includes.
 
+#include <kconfig.h>
 #include <kcursor.h>
-#include <kdebug.h>
 #include <klocale.h>
 #include <knuminput.h>
 #include <kmessagebox.h>
@@ -67,24 +66,20 @@
 #include <kpopupmenu.h>
 #include <kstandarddirs.h>
 
-// Digikam includes.
-
-#include <digikamheaders.h>
-
 // Local includes.
 
 #include "version.h"
 #include "channelmixer.h"
+#include "channelmixer.moc"
 
 namespace DigikamChannelMixerImagesPlugin
 {
 
-ChannelMixerDialog::ChannelMixerDialog(QWidget* parent, uint *imageData, uint width, uint height)
-                  : ImageTabDialog(parent, i18n("Color Channel Mixer"), "channelmixer", 
-                                   true, false, true)
+ChannelMixerDialog::ChannelMixerDialog(QWidget* parent, QString title, QFrame* banner)
+                  : Digikam::ImageDlgBase(parent, title, "channelmixer", true, false, banner)
 {
     m_destinationPreviewData = 0L;
-    
+
     // About data and help button.
 
     KAboutData* about = new KAboutData("digikamimageplugins",
@@ -92,19 +87,27 @@ ChannelMixerDialog::ChannelMixerDialog(QWidget* parent, uint *imageData, uint wi
                                        digikamimageplugins_version,
                                        I18N_NOOP("An image color channel mixer plugin for digiKam."),
                                        KAboutData::License_GPL,
-                                       "(c) 2005, Gilles Caulier",
+                                       "(c) 2005-2007, Gilles Caulier",
                                        0,
                                        "http://extragear.kde.org/apps/digikamimageplugins");
 
     about->addAuthor("Gilles Caulier", I18N_NOOP("Author and maintainer"),
-                     "caulier dot gilles at free.fr");
+                     "caulier dot gilles at gmail dot com");
 
     setAboutData(about);
-    
+
+    // -------------------------------------------------------------
+
+    m_previewWidget = new Digikam::ImageWidget("channelmixer Tool Dialog", plainPage(),
+                          i18n("<p>You can see here the image's color channels' "
+                               "gains adjustments preview. You can pick color on image "
+                               "to see the color level corresponding on histogram."));
+    setPreviewAreaWidget(m_previewWidget); 
+
     // -------------------------------------------------------------
 
     QWidget *gboxSettings = new QWidget(plainPage());
-    QGridLayout* grid = new QGridLayout( gboxSettings, 10, 4, marginHint(), spacingHint());
+    QGridLayout* grid = new QGridLayout( gboxSettings, 9, 4, marginHint(), spacingHint());
 
     QLabel *label1 = new QLabel(i18n("Channel:"), gboxSettings);
     label1->setAlignment ( Qt::AlignRight | Qt::AlignVCenter );
@@ -126,7 +129,7 @@ ChannelMixerDialog::ChannelMixerDialog(QWidget* parent, uint *imageData, uint wi
                                      "If the image's maximal counts are small, you can use the linear scale.<p>"
                                      "Logarithmic scale can be used when the maximal counts are big; "
                                      "if it is used, all values (small and large) will be visible on the graph."));
-    
+
     QPushButton *linHistoButton = new QPushButton( m_scaleBG );
     QToolTip::add( linHistoButton, i18n( "<p>Linear" ) );
     m_scaleBG->insert(linHistoButton, Digikam::HistogramWidget::LinScaleHistogram);
@@ -134,24 +137,24 @@ ChannelMixerDialog::ChannelMixerDialog(QWidget* parent, uint *imageData, uint wi
     QString directory = KGlobal::dirs()->findResourceDir("histogram-lin", "histogram-lin.png");
     linHistoButton->setPixmap( QPixmap( directory + "histogram-lin.png" ) );
     linHistoButton->setToggleButton(true);
-    
+
     QPushButton *logHistoButton = new QPushButton( m_scaleBG );
     QToolTip::add( logHistoButton, i18n( "<p>Logarithmic" ) );
     m_scaleBG->insert(logHistoButton, Digikam::HistogramWidget::LogScaleHistogram);
     KGlobal::dirs()->addResourceType("histogram-log", KGlobal::dirs()->kde_default("data") + "digikam/data");
     directory = KGlobal::dirs()->findResourceDir("histogram-log", "histogram-log.png");
     logHistoButton->setPixmap( QPixmap( directory + "histogram-log.png" ) );
-    logHistoButton->setToggleButton(true);       
+    logHistoButton->setToggleButton(true);
 
     QHBoxLayout* l1 = new QHBoxLayout();
     l1->addWidget(label1);
     l1->addWidget(m_channelCB);
-    l1->addWidget(m_scaleBG);
     l1->addStretch(10);
-    
+    l1->addWidget(m_scaleBG);
+
     grid->addMultiCellLayout(l1, 0, 0, 0, 4);
 
-    m_histogramWidget = new Digikam::HistogramWidget(256, 140, imageData, width, height, gboxSettings, false, true, true);
+    m_histogramWidget = new Digikam::HistogramWidget(256, 140, gboxSettings, false, true, true);
     QWhatsThis::add( m_histogramWidget, i18n("<p>Here you can see the target preview image histogram drawing of the "
                                              "selected image channel. This one is re-computed at any mixer "
                                              "settings changes."));
@@ -183,7 +186,7 @@ ChannelMixerDialog::ChannelMixerDialog(QWidget* parent, uint *imageData, uint wi
     QWhatsThis::add( m_blueGain, i18n("<p>Select here the blue color gain in percent for the current channel."));
 
     m_resetButton = new QPushButton(i18n("&Reset"), gboxSettings);
-    QWhatsThis::add( m_resetButton, i18n("Reset color channels' gains settings from the current selected channel."));
+    QWhatsThis::add( m_resetButton, i18n("Reset color channels' gains settings from the currently selected channel."));
 
     grid->addMultiCellWidget(redLabel, 3, 3, 0, 0);
     grid->addMultiCellWidget(greenLabel, 4, 4, 0, 0);
@@ -196,37 +199,18 @@ ChannelMixerDialog::ChannelMixerDialog(QWidget* parent, uint *imageData, uint wi
     // -------------------------------------------------------------
     
     m_monochrome = new QCheckBox( i18n("Monochrome"), gboxSettings);
-    QWhatsThis::add( m_monochrome, i18n("<p>Enable this option if you want rendering the image in monochrome mode. "
-                                        "In this mode, histogram will display only luminosity values."));
+    QWhatsThis::add( m_monochrome, i18n("<p>Enable this option if you want the image rendered in monochrome mode. "
+                                        "In this mode, the histogram will display only luminosity values."));
     
     m_preserveLuminosity = new QCheckBox( i18n("Preserve luminosity"), gboxSettings);
     QWhatsThis::add( m_preserveLuminosity, i18n("<p>Enable this option is you want preserve the image luminosity."));
     
-    m_overExposureIndicatorBox = new QCheckBox(i18n("Over exposure indicator"), gboxSettings);
-    QWhatsThis::add( m_overExposureIndicatorBox, i18n("<p>If you enable this option, over-exposed pixels "
-                                                      "from the target image preview will be over-colored. "
-                                                      "This will not have an effect on the final rendering."));
-    
     grid->addMultiCellWidget(m_monochrome, 7, 7, 0, 4);
     grid->addMultiCellWidget(m_preserveLuminosity, 8, 8, 0, 4);
-    grid->addMultiCellWidget(m_overExposureIndicatorBox, 9, 9, 0, 4);
-    grid->setRowStretch(10, 10);
+    grid->setRowStretch(9, 10);
     
     setUserAreaWidget(gboxSettings);
     
-    // -------------------------------------------------------------
-
-    m_previewOriginalWidget = previewOriginalWidget();
-    m_previewTargetWidget   = previewTargetWidget();
-    QWhatsThis::add( m_previewTargetWidget, i18n("<p>You can see here the image's color channels' "
-                                                 "gains adjustments preview. You can pick color on image "
-                                                 "to see the color level corresponding on histogram."));
-    
-    // -------------------------------------------------------------
-
-    // Reset all parameters to the default values.
-    QTimer::singleShot(0, this, SLOT(slotDefault()));
-                    
     // -------------------------------------------------------------
     // Channels and scale selection slots.
 
@@ -236,13 +220,10 @@ ChannelMixerDialog::ChannelMixerDialog(QWidget* parent, uint *imageData, uint wi
     connect(m_scaleBG, SIGNAL(released(int)),
             this, SLOT(slotScaleChanged(int)));
 
-    connect(m_previewTargetWidget, SIGNAL(spotPositionChanged( const QColor &, bool, const QPoint & )),
-            this, SLOT(slotColorSelectedFromTarget( const QColor & ))); 
+    connect(m_previewWidget, SIGNAL(spotPositionChangedFromTarget( const Digikam::DColor &, const QPoint & )),
+            this, SLOT(slotColorSelectedFromTarget( const Digikam::DColor & )));
                         
-    connect(m_overExposureIndicatorBox, SIGNAL(toggled (bool)),
-            this, SLOT(slotEffect()));
-    
-    connect(m_previewTargetWidget, SIGNAL(signalResized()),
+    connect(m_previewWidget, SIGNAL(signalResized()),
             this, SLOT(slotEffect()));                             
     
     // -------------------------------------------------------------
@@ -271,10 +252,6 @@ ChannelMixerDialog::ChannelMixerDialog(QWidget* parent, uint *imageData, uint wi
 }
 
 ChannelMixerDialog::~ChannelMixerDialog()
-{
-}
-
-void ChannelMixerDialog::closeEvent(QCloseEvent *e)
 {
     m_histogramWidget->stopHistogramComputation();
 
@@ -282,13 +259,12 @@ void ChannelMixerDialog::closeEvent(QCloseEvent *e)
        delete [] m_destinationPreviewData;
        
     delete m_histogramWidget;
-    e->accept();
 }
 
 void ChannelMixerDialog::slotResetCurrentChannel()
 {
     switch( m_channelCB->currentItem() )
-       {
+    {
        case GreenChannelGains:           // Green.
           m_greenRedGain   = 0.0;
           m_greenGreenGain = 1.0;
@@ -303,63 +279,63 @@ void ChannelMixerDialog::slotResetCurrentChannel()
 
        default:          // Red or monochrome.
           if ( m_monochrome->isChecked() )
-             {
+          {
              m_blackRedGain   = 1.0;
              m_blackGreenGain = 0.0;
              m_blackBlueGain  = 0.0;
-             }
+          }
           else
-             {
+          {
              m_redRedGain   = 1.0;
              m_redGreenGain = 0.0;
              m_redBlueGain  = 0.0;
-             }
+          }
           break;
-       }
+    }
     
     adjustSliders();
     slotEffect();
     m_histogramWidget->reset();
 }
 
-void ChannelMixerDialog::slotColorSelectedFromTarget( const QColor &color )
+void ChannelMixerDialog::slotColorSelectedFromTarget( const Digikam::DColor &color )
 {
-    m_histogramWidget->setHistogramGuide(color);
+    m_histogramWidget->setHistogramGuideByColor(color);
 }
 
 void ChannelMixerDialog::slotGainsChanged()
 {
     switch( m_channelCB->currentItem() )
-       {
+    {
        case GreenChannelGains:           // Green.
-          m_greenRedGain   = m_redGain->value() / 100.0;
+          m_greenRedGain   = m_redGain->value()   / 100.0;
           m_greenGreenGain = m_greenGain->value() / 100.0;
-          m_greenBlueGain  = m_blueGain->value() / 100.0;
+          m_greenBlueGain  = m_blueGain->value()  / 100.0;
           break;
 
        case BlueChannelGains:            // Blue.
-          m_blueRedGain   = m_redGain->value() / 100.0;
+          m_blueRedGain   = m_redGain->value()   / 100.0;
           m_blueGreenGain = m_greenGain->value() / 100.0;
-          m_blueBlueGain  = m_blueGain->value() / 100.0;
+          m_blueBlueGain  = m_blueGain->value()  / 100.0;
           break;
 
        default:          // Red or monochrome.
           if ( m_monochrome->isChecked() )
-             {
-             m_blackRedGain   = m_redGain->value() / 100.0;
+          {
+             m_blackRedGain   = m_redGain->value()   / 100.0;
              m_blackGreenGain = m_greenGain->value() / 100.0;
-             m_blackBlueGain  = m_blueGain->value() / 100.0;
-             }
+             m_blackBlueGain  = m_blueGain->value()  / 100.0;
+          }
           else
-             {
-             m_redRedGain   = m_redGain->value() / 100.0;
+          {
+             m_redRedGain   = m_redGain->value()   / 100.0;
              m_redGreenGain = m_greenGain->value() / 100.0;
-             m_redBlueGain  = m_blueGain->value() / 100.0;
-             }
+             m_redBlueGain  = m_blueGain->value()  / 100.0;
+          }
           break;
-       }
+    }
 
-    slotEffect();
+    slotTimer();
 }
 
 void ChannelMixerDialog::adjustSliders(void)
@@ -369,34 +345,34 @@ void ChannelMixerDialog::adjustSliders(void)
     m_blueGain->blockSignals(true);
 
     switch( m_channelCB->currentItem() )
-       {
+    {
        case GreenChannelGains:           // Green.
-          m_redGain->setValue(m_greenRedGain * 100.0);
+          m_redGain->setValue(m_greenRedGain     * 100.0);
           m_greenGain->setValue(m_greenGreenGain * 100.0);
-          m_blueGain->setValue(m_greenBlueGain * 100.0);
+          m_blueGain->setValue(m_greenBlueGain   * 100.0);
           break;
 
        case BlueChannelGains:            // Blue.
-          m_redGain->setValue(m_blueRedGain * 100.0);
+          m_redGain->setValue(m_blueRedGain     * 100.0);
           m_greenGain->setValue(m_blueGreenGain * 100.0);
-          m_blueGain->setValue(m_blueBlueGain * 100.0);
+          m_blueGain->setValue(m_blueBlueGain   * 100.0);
           break;
 
        default:          // Red or monochrome.
           if ( m_monochrome->isChecked() )
-             {
-             m_redGain->setValue(m_blackRedGain * 100.0);
+          {
+             m_redGain->setValue(m_blackRedGain     * 100.0);
              m_greenGain->setValue(m_blackGreenGain * 100.0);
-             m_blueGain->setValue(m_blackBlueGain * 100.0);
-             }
+             m_blueGain->setValue(m_blackBlueGain   * 100.0);
+          }
           else
-             {
-             m_redGain->setValue(m_redRedGain * 100.0);
+          {
+             m_redGain->setValue(m_redRedGain     * 100.0);
              m_greenGain->setValue(m_redGreenGain * 100.0);
-             m_blueGain->setValue(m_redBlueGain * 100.0);
-             }
+             m_blueGain->setValue(m_redBlueGain   * 100.0);
+          }
           break;
-       }
+    }
     
     m_redGain->blockSignals(false);
     m_greenGain->blockSignals(false);
@@ -412,101 +388,89 @@ void ChannelMixerDialog::slotMonochromeActived(bool mono)
 
 void ChannelMixerDialog::slotEffect()
 {
-    Digikam::ImageIface* ifaceDest = m_previewTargetWidget->imageIface();
-
-    uint* orgData = ifaceDest->getPreviewData();
-    int   w       = ifaceDest->previewWidth();
-    int   h       = ifaceDest->previewHeight();
-    bool  l       = m_preserveLuminosity->isChecked();
-    bool  m       = m_monochrome->isChecked();
-
+    Digikam::ImageIface* iface = m_previewWidget->imageIface();
+    uchar *data                = iface->getPreviewImage();
+    int w                      = iface->previewWidth();
+    int h                      = iface->previewHeight();
+    bool sb                    = iface->previewSixteenBit();
+    
     // Create the new empty destination image data space.
     m_histogramWidget->stopHistogramComputation();
 
     if (m_destinationPreviewData) 
        delete [] m_destinationPreviewData;
     
-    m_destinationPreviewData = new uint[w*h];
+    m_destinationPreviewData = new uchar[w*h*(sb ? 8 : 4)];
+    Digikam::DImgImageFilters filter;
 
-    memcpy (m_destinationPreviewData, orgData, w*h*4);  
-
-    if (m)
-       {
-       Digikam::ImageFilters::channelMixerImage(m_destinationPreviewData, w, h,    // Image data.
-                l,                                                                 // Preserve luminosity.    
-                m,                                                                 // Monochrome.
-                m_blackRedGain, m_blackGreenGain, m_blackBlueGain,                 // Red channel gains.
-                0.0,            1.0,              0.0,                             // Green channel gains (not used).
-                0.0,            0.0,              1.0,                             // Blue channel gains (not used).
-                m_overExposureIndicatorBox->isChecked());
-       }
+    if (m_monochrome->isChecked())
+    {
+       filter.channelMixerImage(data, w, h, sb,                                 // Image data.
+                m_preserveLuminosity->isChecked(),                              // Preserve luminosity.
+                m_monochrome->isChecked(),                                      // Monochrome.
+                m_blackRedGain, m_blackGreenGain, m_blackBlueGain,              // Red channel gains.
+                0.0,            1.0,              0.0,                          // Green channel gains (not used).
+                0.0,            0.0,              1.0);                         // Blue channel gains (not used).
+    }
     else
-       {
-       Digikam::ImageFilters::channelMixerImage(m_destinationPreviewData, w, h,    // Image data.
-                l,                                                                 // Preserve luminosity.    
-                m,                                                                 // Monochrome.
-                m_redRedGain,   m_redGreenGain,   m_redBlueGain,                   // Red channel gains.
-                m_greenRedGain, m_greenGreenGain, m_greenBlueGain,                 // Green channel gains.
-                m_blueRedGain,  m_blueGreenGain,  m_blueBlueGain,                  // Blue channel gains.
-                m_overExposureIndicatorBox->isChecked());
-       }
+    {
+       filter.channelMixerImage(data, w, h, sb,                                 // Image data.
+                m_preserveLuminosity->isChecked(),                              // Preserve luminosity.
+                m_monochrome->isChecked(),                                      // Monochrome.
+                m_redRedGain,   m_redGreenGain,   m_redBlueGain,                // Red channel gains.
+                m_greenRedGain, m_greenGreenGain, m_greenBlueGain,              // Green channel gains.
+                m_blueRedGain,  m_blueGreenGain,  m_blueBlueGain);              // Blue channel gains.
+    }
     
-    ifaceDest->putPreviewData(m_destinationPreviewData);
-    m_previewTargetWidget->updatePreview();
+    iface->putPreviewImage(data);
+    m_previewWidget->updatePreview();
     
     // Update histogram.
-    m_histogramWidget->updateData(m_destinationPreviewData, w, h, 0, 0, 0, false); 
-    
-    delete [] orgData;
+    memcpy (m_destinationPreviewData, data, w*h*(sb ? 8 : 4));
+    m_histogramWidget->updateData(m_destinationPreviewData, w, h, sb, 0, 0, 0, false);
+    delete [] data;
 }
 
-void ChannelMixerDialog::slotOk()
+void ChannelMixerDialog::finalRendering()
 {
     kapp->setOverrideCursor( KCursor::waitCursor() );
-    Digikam::ImageIface ifaceDest(0, 0);
+    Digikam::ImageIface* iface = m_previewWidget->imageIface();
+    uchar *data                = iface->getOriginalImage();
+    int w                      = iface->originalWidth();
+    int h                      = iface->originalHeight();
+    bool sb                    = iface->originalSixteenBit();
 
-    uint* orgData = ifaceDest.getOriginalData();
-    int   w       = ifaceDest.originalWidth();
-    int   h       = ifaceDest.originalHeight();
-    bool  l       = m_preserveLuminosity->isChecked();
-    bool  m       = m_monochrome->isChecked();
+    Digikam::DImgImageFilters filter;
 
-    // Create the new empty destination image data space.
-    uint* desData = new uint[w*h];
-
-    memcpy (desData, orgData, w*h*4);  
-
-    if (m)
-       {
-       Digikam::ImageFilters::channelMixerImage(desData, w, h,      // Image data.
-                l,                                                  // Preserve luminosity.    
-                m,                                                  // Monochrome.
+    if (m_monochrome->isChecked())
+    {
+       filter.channelMixerImage(data, w, h, sb,                     // Image data.
+                m_preserveLuminosity->isChecked(),                  // Preserve luminosity.
+                m_monochrome->isChecked(),                          // Monochrome.
                 m_blackRedGain, m_blackGreenGain, m_blackBlueGain,  // Red channel gains.
                 0.0,            1.0,              0.0,              // Green channel gains (not used).
                 0.0,            0.0,              1.0);             // Blue channel gains (not used).
-       }
+    }
     else
-       {
-       Digikam::ImageFilters::channelMixerImage(desData, w, h,      // Image data.
-                l,                                                  // Preserve luminosity.    
-                m,                                                  // Monochrome.
+    {
+       filter.channelMixerImage(data, w, h, sb,                     // Image data.
+                m_preserveLuminosity->isChecked(),                  // Preserve luminosity.
+                m_monochrome->isChecked(),                          // Monochrome.
                 m_redRedGain,   m_redGreenGain,   m_redBlueGain,    // Red channel gains.
                 m_greenRedGain, m_greenGreenGain, m_greenBlueGain,  // Green channel gains.
                 m_blueRedGain,  m_blueGreenGain,  m_blueBlueGain);  // Blue channel gains.
-       }
-    
-    ifaceDest.putOriginalData(i18n("Channel Mixer"), desData);
-    kapp->restoreOverrideCursor();
+    }
 
-    delete [] orgData;
-    delete [] desData;
+    iface->putOriginalImage(i18n("Channel Mixer"), data);
+    delete [] data;
+    kapp->restoreOverrideCursor();
     accept();
 }
 
 void ChannelMixerDialog::slotChannelChanged(int channel)
 {
     switch(channel)
-       {
+    {
        case GreenChannelGains:           // Green.
           m_histogramWidget->m_channelType = Digikam::HistogramWidget::GreenChannelHistogram;
           m_hGradient->setColors( QColor( "black" ), QColor( "green" ) );
@@ -519,17 +483,17 @@ void ChannelMixerDialog::slotChannelChanged(int channel)
 
        default:          // Red or monochrome.
           if ( m_monochrome->isChecked() )
-             {
+          {
              m_histogramWidget->m_channelType = Digikam::HistogramWidget::ValueHistogram;
              m_hGradient->setColors( QColor( "black" ), QColor( "white" ) );          
-             }
+          }
           else
-             {
+          {
              m_histogramWidget->m_channelType = Digikam::HistogramWidget::RedChannelHistogram;
              m_hGradient->setColors( QColor( "black" ), QColor( "red" ) );          
-             }
+          }
           break;
-       }
+    }
 
     m_histogramWidget->repaint(false);
     adjustSliders();
@@ -542,27 +506,89 @@ void ChannelMixerDialog::slotScaleChanged(int scale)
     m_histogramWidget->repaint(false);
 }
 
-// Reset all gains.
-void ChannelMixerDialog::slotDefault()
+void ChannelMixerDialog::readUserSettings()
+{
+    KConfig* config = kapp->config();
+    config->setGroup("channelmixer Tool Dialog");
+
+    m_channelCB->setCurrentItem(config->readNumEntry("Histogram Channel", 0));    // Luminosity.
+    m_scaleBG->setButton(config->readNumEntry("Histogram Scale", Digikam::HistogramWidget::LogScaleHistogram));
+
+    m_monochrome->setChecked(config->readBoolEntry("Monochrome", false));
+    m_preserveLuminosity->setChecked(config->readNumEntry("PreserveLuminosity", false));
+
+    m_redRedGain     = config->readDoubleNumEntry("RedRedGain", 1.0); 
+    m_redGreenGain   = config->readDoubleNumEntry("RedGreenGain", 0.0); 
+    m_redBlueGain    = config->readDoubleNumEntry("RedBlueGain", 0.0); 
+    
+    m_greenRedGain   = config->readDoubleNumEntry("GreenRedGain", 0.0);
+    m_greenGreenGain = config->readDoubleNumEntry("GreenGreenGain", 1.0); 
+    m_greenBlueGain  = config->readDoubleNumEntry("GreenBlueGain", 0.0);
+    
+    m_blueRedGain    = config->readDoubleNumEntry("BlueRedGain", 0.0);
+    m_blueGreenGain  = config->readDoubleNumEntry("BlueGreenGain", 0.0);
+    m_blueBlueGain   = config->readDoubleNumEntry("BlueBlueGain", 1.0);
+
+    m_blackRedGain   = config->readDoubleNumEntry("BlackRedGain", 1.0); 
+    m_blackGreenGain = config->readDoubleNumEntry("BlackGreenGain", 0.0); 
+    m_blackBlueGain  = config->readDoubleNumEntry("BlackBlueGain", 0.0); 
+
+    adjustSliders();
+    m_histogramWidget->reset();
+
+    slotChannelChanged(m_channelCB->currentItem());
+    slotScaleChanged(m_scaleBG->selectedId());
+}
+
+void ChannelMixerDialog::writeUserSettings()
+{
+    KConfig* config = kapp->config();
+    config->setGroup("channelmixer Tool Dialog");
+    config->writeEntry("Histogram Channel", m_channelCB->currentItem());
+    config->writeEntry("Histogram Scale", m_scaleBG->selectedId());
+
+    config->writeEntry("Monochrome", m_monochrome->isChecked());
+    config->writeEntry("PreserveLuminosity", m_preserveLuminosity->isChecked());
+
+    config->writeEntry("RedRedGain", m_redRedGain);
+    config->writeEntry("RedGreenGain", m_redGreenGain);
+    config->writeEntry("RedBlueGain", m_redBlueGain);
+
+    config->writeEntry("GreenRedGain", m_greenRedGain);
+    config->writeEntry("GreenGreenGain", m_greenGreenGain);
+    config->writeEntry("GreenBlueGain", m_greenBlueGain);
+
+    config->writeEntry("BlueRedGain", m_blueRedGain);
+    config->writeEntry("BlueGreenGain", m_blueGreenGain);
+    config->writeEntry("BlueBlueGain", m_blueBlueGain);
+
+    config->writeEntry("BlackRedGain", m_blackRedGain);
+    config->writeEntry("BlackGreenGain", m_blackGreenGain);
+    config->writeEntry("BlackBlueGain", m_blackBlueGain);
+
+    config->sync();
+}
+
+void ChannelMixerDialog::resetValues()
 {
     m_monochrome->blockSignals(true);
     m_preserveLuminosity->blockSignals(true);
     
-    m_redRedGain = 1.0; 
-    m_redGreenGain = 0.0; 
-    m_redBlueGain = 0.0; 
+    m_redRedGain     = 1.0; 
+    m_redGreenGain   = 0.0; 
+    m_redBlueGain    = 0.0; 
     
-    m_greenRedGain = 0.0;
+    m_greenRedGain   = 0.0;
     m_greenGreenGain = 1.0; 
-    m_greenBlueGain = 0.0;
+    m_greenBlueGain  = 0.0;
     
-    m_blueRedGain = 0.0;
-    m_blueGreenGain = 0.0;
-    m_blueBlueGain = 1.0;
+    m_blueRedGain    = 0.0;
+    m_blueGreenGain  = 0.0;
+    m_blueBlueGain   = 1.0;
 
-    m_blackRedGain = 1.0; 
+    m_blackRedGain   = 1.0; 
     m_blackGreenGain = 0.0; 
-    m_blackBlueGain = 0.0; 
+    m_blackBlueGain  = 0.0; 
 
     adjustSliders();
     
@@ -572,7 +598,7 @@ void ChannelMixerDialog::slotDefault()
     
     m_histogramWidget->reset();
 
-    slotEffect();
+    slotChannelChanged(RedChannelGains);
 }
 
 // Load all gains.
@@ -592,7 +618,7 @@ void ChannelMixerDialog::slotUser3()
     fp = fopen(QFile::encodeName(loadGainsFileUrl.path()), "r");   
     
     if ( fp )
-        {
+    {
         char buf1[1024];
         char buf2[1024];
         char buf3[1024];
@@ -654,12 +680,12 @@ void ChannelMixerDialog::slotUser3()
         m_monochrome->setChecked(monochrome);
         m_channelCB->setCurrentItem(currentOutputChannel);
         slotChannelChanged(currentOutputChannel);
-        }
+    }
     else
-        {
+    {
         KMessageBox::error(this, i18n("Cannot load settings from the Gains Mixer text file."));
         return;
-        }
+    }
 }
 
 // Save all gains.
@@ -677,14 +703,14 @@ void ChannelMixerDialog::slotUser2()
     fp = fopen(QFile::encodeName(saveGainsFileUrl.path()), "w");   
     
     if ( fp )
-        {       
+    {
         const char *str = 0L;
         char        buf1[256];
         char        buf2[256];
         char        buf3[256];
 
         switch ( m_channelCB->currentItem() )
-           {
+        {
            case RedChannelGains:
               str = "RED";
               break;
@@ -695,9 +721,9 @@ void ChannelMixerDialog::slotUser2()
               str = "BLUE";
               break;
            default:
-              kdWarning() <<  "Unknown Color channel gains" << endl;;
+              DWarning() <<  "Unknown Color channel gains" << endl;
               break;
-           }
+        }
 
         fprintf (fp, "# Channel Mixer Configuration File\n");
 
@@ -729,14 +755,13 @@ void ChannelMixerDialog::slotUser2()
         fprintf (fp, "BLACK: %s %s %s\n", buf1, buf2,buf3);
         
         fclose (fp);
-        }
+    }
     else
-        {
+    {
         KMessageBox::error(this, i18n("Cannot save settings to the Gains Mixer text file."));
         return;
-        }
+    }
 }
 
 }  // NameSpace DigikamChannelMixerImagesPlugin
 
-#include "channelmixer.moc"
