@@ -1,5 +1,5 @@
 /* ============================================================
- * Author: Gilles Caulier <caulier dot gilles at free.fr>
+ * Author: Gilles Caulier <caulier dot gilles at gmail dot com>
  * Date  : 2005-07-07
  * Description : a nice banner widget.
  * 
@@ -35,7 +35,7 @@ Q_OBJECT
 
 public:
 
-    BannerWidget(QWidget *parent=0, QString title=QString::null);
+    BannerWidget(QWidget *parent=0, QString title=QString());
     ~BannerWidget();
 
 private slots:        
