@@ -1,11 +1,10 @@
 /* ============================================================
- * File  : imageeffect_freerotation.h
- * Author: Gilles Caulier <caulier dot gilles at free.fr>
- * Date  : 2004-11-28
+ * Authors: Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Date   : 2004-11-28
  * Description : a digiKam image editor plugin to process image 
  *               free rotation.
  * 
- * Copyright 2004-2005 by Gilles Caulier
+ * Copyright 2004-2007 by Gilles Caulier
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -25,8 +24,9 @@
 
 // Local includes.
 
-#include "imageguidedialog.h"
+#include <digikamheaders.h>
 
+class QFrame;
 class QLabel;
 class QCheckBox;
 class QComboBox;
@@ -37,15 +37,29 @@ class KDoubleNumInput;
 namespace DigikamFreeRotationImagesPlugin
 {
 
-class ImageEffect_FreeRotation : public DigikamImagePlugins::ImageGuideDialog
+class ImageEffect_FreeRotation : public Digikam::ImageGuideDlg
 {
     Q_OBJECT
     
 public:
 
-    ImageEffect_FreeRotation(QWidget *parent);
+    ImageEffect_FreeRotation(QWidget *parent, QString title, QFrame* banner);
     ~ImageEffect_FreeRotation();
 
+private slots:
+    
+    void readUserSettings(void);
+
+protected:
+
+    void writeUserSettings();    
+    void resetValues();   
+    void prepareEffect();
+    void prepareFinal();
+    void putPreviewData();
+    void putFinalData();
+    void renderingFinished();
+
 private:
 
     QLabel           *m_newWidthLabel;
@@ -58,20 +72,6 @@ private:
     KIntNumInput     *m_angleInput;
 
     KDoubleNumInput  *m_fineAngleInput;
-
-private slots:
-    
-    void readUserSettings(void);
-
-protected:
-
-    void writeUserSettings(void);    
-    void prepareEffect(void);
-    void prepareFinal(void);
-    void putPreviewData(void);
-    void putFinalData(void);
-    void resetValues(void);   
-    void renderingFinished(void);
 };
 
 }  // NameSpace DigikamFreeRotationImagesPlugin
