@@ -1,10 +1,9 @@
 /* ============================================================
- * File  : imageplugin_freerotation.cpp
- * Author: Gilles Caulier <caulier dot gilles at free.fr>
- * Date  : 2004-11-28
+ * Authors: Gilles Caulier
+ * Date   : 2004-11-28
  * Description : 
  * 
- * Copyright 2004-2005 by Gilles Caulier
+ * Copyright 2004-2007 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -26,12 +25,13 @@
 #include <klibloader.h>
 #include <kaction.h>
 #include <kcursor.h>
-#include <kdebug.h>
 
 // Local includes.
 
+#include "bannerwidget.h"
 #include "imageeffect_freerotation.h"
 #include "imageplugin_freerotation.h"
+#include "imageplugin_freerotation.moc"
 
 K_EXPORT_COMPONENT_FACTORY( digikamimageplugin_freerotation,
                             KGenericFactory<ImagePlugin_FreeRotation>("digikamimageplugin_freerotation"));
@@ -45,7 +45,7 @@ ImagePlugin_FreeRotation::ImagePlugin_FreeRotation(QObject *parent, const char*,
     
     setXMLFile("digikamimageplugin_freerotation_ui.rc");         
                                     
-    kdDebug() << "ImagePlugin_FreeRotation plugin loaded" << endl;
+    DDebug() << "ImagePlugin_FreeRotation plugin loaded" << endl;
 }
 
 ImagePlugin_FreeRotation::~ImagePlugin_FreeRotation()
@@ -59,9 +59,10 @@ void ImagePlugin_FreeRotation::setEnabledActions(bool enable)
 
 void ImagePlugin_FreeRotation::slotFreeRotation()
 {
-    DigikamFreeRotationImagesPlugin::ImageEffect_FreeRotation dlg(parentWidget());
+    QString title = i18n("Free Rotation");
+    QFrame *headerFrame = new DigikamImagePlugins::BannerWidget(0, title);
+    DigikamFreeRotationImagesPlugin::ImageEffect_FreeRotation dlg(parentWidget(),
+                                title, headerFrame);
     dlg.exec();
+    delete headerFrame;
 }
-
-
-#include "imageplugin_freerotation.moc"
