@@ -1,10 +1,9 @@
 /* ============================================================
- * File  : imageplugin_infrared.h
- * Author: Gilles Caulier <caulier dot gilles at free.fr>
- * Date  : 2005-02-22
+ * Authors: Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Date   : 2005-02-22
  * Description : 
  * 
- * Copyright 2005 by Gilles Caulier
+ * Copyright 2005-2007 by Gilles Caulier
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -19,7 +18,6 @@
  * 
  * ============================================================ */
 
-
 #ifndef IMAGEPLUGIN_INFRARED_H
 #define IMAGEPLUGIN_INFRARED_H
 
@@ -29,7 +27,7 @@
 
 class KAction;
 
-class ImagePlugin_Infrared : public Digikam::ImagePlugin
+class DIGIKAMIMAGEPLUGINS_EXPORT ImagePlugin_Infrared : public Digikam::ImagePlugin
 {
     Q_OBJECT
     
@@ -41,14 +39,13 @@ public:
 
     void setEnabledActions(bool enable);
 
-private:
-
-    KAction *m_infraredAction;
-    
 private slots:
 
     void slotInfrared();
 
+private:
+
+    KAction *m_infraredAction;
 };
     
 #endif /* IMAGEPLUGIN_INFRARED_H */
