@@ -1,11 +1,11 @@
 /* ============================================================
  * File  : imageeffect_inpainting.cpp
- * Author: Gilles Caulier <caulier dot gilles at free.fr>
+ * Author: Gilles Caulier <caulier dot gilles at gmail dot com>
  * Date  : 2005-03-30
  * Description : a digiKam image editor plugin to inpaint
  *               a photograph
  *
- * Copyright 2005 by Gilles Caulier
+ * Copyright 2005 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -61,13 +61,8 @@
 #include <kmessagebox.h>
 #include <knuminput.h>
 #include <kglobalsettings.h>
-#include <kdebug.h>
 #include <kpassivepopup.h>
 
-// Digikam includes.
-
-#include <digikamheaders.h>
-
 // Local includes.
 
 #include "version.h"
@@ -128,7 +123,7 @@ ImageEffect_InPainting_Dialog::ImageEffect_InPainting_Dialog(QWidget* parent)
                              : KDialogBase(Plain, i18n("Photograph Inpainting"),
                                            Help|Default|User2|User3|Ok|Cancel, Ok,
                                            parent, 0, true, true,
-                                           QString::null,
+                                           QString(),
                                            i18n("&Save As..."),
                                            i18n("&Load...")),
                                m_parent(parent)
@@ -144,16 +139,16 @@ ImageEffect_InPainting_Dialog::ImageEffect_InPainting_Dialog(QWidget* parent)
     // About data and help button.
 
     m_about = new KAboutData("digikamimageplugins",
-                                       I18N_NOOP("Photograph Inpainting"),
-                                       digikamimageplugins_version,
-                                       I18N_NOOP("A digiKam image plugin to inpaint a photograph."),
-                                       KAboutData::License_GPL,
-                                       "(c) 2005, Gilles Caulier",
-                                       0,
-                                       "http://extragear.kde.org/apps/digikamimageplugins");
+                             I18N_NOOP("Photograph Inpainting"),
+                             digikamimageplugins_version,
+                             I18N_NOOP("A digiKam image plugin to inpaint a photograph."),
+                             KAboutData::License_GPL,
+                             "(c) 2005, Gilles Caulier",
+                             0,
+                             "http://extragear.kde.org/apps/digikamimageplugins");
 
     m_about->addAuthor("Gilles Caulier", I18N_NOOP("Author and maintainer"),
-                       "caulier dot gilles at free.fr");
+                       "caulier dot gilles at gmail dot com");
 
     m_about->addAuthor("David Tschumperle", I18N_NOOP("CImg library"), 0,
                        "http://cimg.sourceforge.net");
@@ -184,7 +179,7 @@ ImageEffect_InPainting_Dialog::ImageEffect_InPainting_Dialog(QWidget* parent)
     m_mainTab->addTab( firstPage, i18n("Preset") );
 
     KURLLabel *cimgLogoLabel = new KURLLabel(firstPage);
-    cimgLogoLabel->setText(QString::null);
+    cimgLogoLabel->setText(QString());
     cimgLogoLabel->setURL("http://cimg.sourceforge.net");
     KGlobal::dirs()->addResourceType("cimg-logo", KGlobal::dirs()->kde_default("data") + "digikamimageplugins/data");
     QString directory = KGlobal::dirs()->findResourceDir("cimg-logo", "cimg-logo.png");
@@ -339,7 +334,7 @@ ImageEffect_InPainting_Dialog::ImageEffect_InPainting_Dialog(QWidget* parent)
 ImageEffect_InPainting_Dialog::~ImageEffect_InPainting_Dialog()
 {
     delete m_about;
-    
+
     if (m_cimgInterface)
        delete m_cimgInterface;
 }
@@ -375,28 +370,28 @@ void ImageEffect_InPainting_Dialog::slotDefault()
     m_normalizeBox->setChecked(false);
 
     switch(m_inpaintingTypeCB->currentItem())
-        {
+    {
         case RemoveSmallArtefact:
-            {
+        {
             m_timeStepInput->setValue(20.0);
             m_blurItInput->setValue(30.0);
             break;
-            }
+        }
 
         case RemoveMediumArtefact:
-            {
+        {
             m_timeStepInput->setValue(50.0);
             m_blurItInput->setValue(50.0);
             break;
-            }
+        }
 
         case RemoveLargeArtefact:
-            {
+        {
             m_timeStepInput->setValue(100.0);
             m_blurItInput->setValue(100.0);
             break;
-            }
         }
+    }
 
     m_detailInput->blockSignals(false);
     m_gradientInput->blockSignals(false);
@@ -413,10 +408,10 @@ void ImageEffect_InPainting_Dialog::slotDefault()
 void ImageEffect_InPainting_Dialog::slotCancel()
 {
     if (m_currentRenderingMode != NoneRendering)
-       {
+    {
        m_cimgInterface->stopComputation();
-       m_parent->setCursor( KCursor::arrowCursor() );
-       }
+       m_parent->unsetCursor();
+    }
 
     done(Cancel);
 }
@@ -434,10 +429,10 @@ void ImageEffect_InPainting_Dialog::processCImgURL(const QString& url)
 void ImageEffect_InPainting_Dialog::closeEvent(QCloseEvent *e)
 {
     if (m_currentRenderingMode != NoneRendering)
-       {
+    {
        m_cimgInterface->stopComputation();
-       m_parent->setCursor( KCursor::arrowCursor() );
-       }
+       m_parent->unsetCursor();
+    }
 
     e->accept();
 }
@@ -465,9 +460,10 @@ void ImageEffect_InPainting_Dialog::slotOk()
     m_progressBar->setValue(0);
 
     Digikam::ImageIface iface(0, 0);
-    m_originalImage = QImage(iface.originalWidth(), iface.originalHeight(), 32);
-    uint *data = iface.getOriginalData();
-    memcpy( m_originalImage.bits(), data, m_originalImage.numBytes() );
+    uchar *data = iface.getOriginalImage();
+    m_originalImage = Digikam::DImg(iface.originalWidth(), iface.originalHeight(),
+                                    iface.originalSixteenBit(), iface.originalHasAlpha(), data);
+    delete [] data;
 
     // Selected area from the image and mask creation:
     //
@@ -488,7 +484,7 @@ void ImageEffect_InPainting_Dialog::slotOk()
     QPixmap inPaintingMask(iface.originalWidth(), iface.originalHeight());
     inPaintingMask.fill(Qt::black);
     QPainter p(&inPaintingMask);
-    p.fillRect( selectionRect, QBrush::QBrush(Qt::white) );
+    p.fillRect( selectionRect, QBrush(Qt::white) );
     p.end();
 
     int x1 = (int)(selectionRect.left()   - 2*m_timeStepInput->value());
@@ -524,7 +520,6 @@ void ImageEffect_InPainting_Dialog::slotOk()
                                     m_linearInterpolationBox->isChecked(),
                                     false, true, false, NULL, 0, 0,
                                     &m_maskImage, this);
-    delete [] data;
 }
 
 void ImageEffect_InPainting_Dialog::customEvent(QCustomEvent *event)
@@ -536,31 +531,30 @@ void ImageEffect_InPainting_Dialog::customEvent(QCustomEvent *event)
     if (!d) return;
 
     if (d->starting)           // Computation in progress !
-        {
+    {
         m_progressBar->setValue(d->progress);
-        }
+    }
     else
-        {
+    {
         if (d->success)        // Computation Completed !
-            {
+        {
             switch (m_currentRenderingMode)
-              {
-              case FinalRendering:
-                 {
-                 kdDebug() << "Final InPainting completed..." << endl;
-                 Digikam::ImageIface iface(0, 0);
-                 QImage target = m_cimgInterface->getTargetImage();
-                 bitBlt(&m_originalImage, m_maskRect.left(), m_maskRect.top(),
-                        &target, 0, 0, target.width(), target.height());
-
-                 iface.putOriginalData(i18n("InPainting"), (uint*)m_originalImage.bits());
-
-                 m_parent->setCursor( KCursor::arrowCursor() );
-                 accept();
-                 break;
-                 }
-              }
+            {
+                case FinalRendering:
+                {
+                    DDebug() << "Final InPainting completed..." << endl;
+                    Digikam::ImageIface iface(0, 0);
+                    Digikam::DImg target = m_cimgInterface->getTargetImage();
+                    m_originalImage.bitBltImage(&target, m_maskRect.left(), m_maskRect.top());
+    
+                    iface.putOriginalImage(i18n("InPainting"), m_originalImage.bits());
+    
+                    m_parent->unsetCursor();
+                    accept();
+                    break;
+                }
             }
+        }
         else                   // Computation Failed !
             {
             switch (m_currentRenderingMode)
@@ -585,16 +579,16 @@ void ImageEffect_InPainting_Dialog::slotUser3()
     QFile file(loadInpaintingFile.path());
 
     if ( file.open(IO_ReadOnly) )
-        {
+    {
         QTextStream stream( &file );
         if ( stream.readLine() != "# Photograph Inpainting Configuration File" )
-           {
+        {
            KMessageBox::error(this,
                         i18n("\"%1\" is not a Photograph Inpainting settings text file.")
                         .arg(loadInpaintingFile.fileName()));
            file.close();
            return;
-           }
+        }
 
         blockSignals(true);
         m_normalizeBox->setChecked( stream.readLine().toInt() );
@@ -609,7 +603,7 @@ void ImageEffect_InPainting_Dialog::slotUser3()
         m_integralStepInput->setValue( stream.readLine().toDouble() );
         m_gaussianInput->setValue( stream.readLine().toDouble() );
         blockSignals(false);
-        }
+    }
     else
         KMessageBox::error(this, i18n("Cannot load settings from the Photograph Inpainting text file."));
 
@@ -627,7 +621,7 @@ void ImageEffect_InPainting_Dialog::slotUser2()
     QFile file(saveRestorationFile.path());
 
     if ( file.open(IO_WriteOnly) )
-        {
+    {
         QTextStream stream( &file );
         stream << "# Photograph Inpainting Configuration File\n";
         stream << m_normalizeBox->isChecked() << "\n";
@@ -640,7 +634,7 @@ void ImageEffect_InPainting_Dialog::slotUser2()
         stream << m_angularStepInput->value() << "\n";
         stream << m_integralStepInput->value() << "\n";
         stream << m_gaussianInput->value() << "\n";
-        }
+    }
     else
         KMessageBox::error(this, i18n("Cannot save settings to the Photograph Inpainting text file."));
 
