@@ -1,10 +1,9 @@
 /* ============================================================
- * File  : imageplugin_lensdistortion.cpp
- * Author: Gilles Caulier <caulier dot gilles at free.fr>
- * Date  : 2004-12-27
+ * Authors: Gilles Caulier
+ * Date   : 2004-12-27
  * Description : 
  * 
- * Copyright 2004-2005 by Gilles Caulier
+ * Copyright 2004-2007 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -26,18 +25,19 @@
 #include <klibloader.h>
 #include <kaction.h>
 #include <kcursor.h>
-#include <kdebug.h>
 
 // Local includes.
 
+#include "bannerwidget.h"
 #include "imageeffect_lensdistortion.h"
 #include "imageplugin_lensdistortion.h"
+#include "imageplugin_lensdistortion.moc"
 
 K_EXPORT_COMPONENT_FACTORY( digikamimageplugin_lensdistortion,
                             KGenericFactory<ImagePlugin_LensDistortion>("digikamimageplugin_lensdistortion"));
 
 ImagePlugin_LensDistortion::ImagePlugin_LensDistortion(QObject *parent, const char*, const QStringList &)
-                            : Digikam::ImagePlugin(parent, "ImagePlugin_LensDistortion")
+                          : Digikam::ImagePlugin(parent, "ImagePlugin_LensDistortion")
 {
     m_lensdistortionAction = new KAction(i18n("Lens Distortion Correction..."), "lensdistortion", 0, 
                                  this, SLOT(slotLensDistortion()),
@@ -45,7 +45,7 @@ ImagePlugin_LensDistortion::ImagePlugin_LensDistortion(QObject *parent, const ch
     
     setXMLFile("digikamimageplugin_lensdistortion_ui.rc");            
         
-    kdDebug() << "ImagePlugin_LensDistortion plugin loaded" << endl;
+    DDebug() << "ImagePlugin_LensDistortion plugin loaded" << endl;
 }
 
 ImagePlugin_LensDistortion::~ImagePlugin_LensDistortion()
@@ -59,9 +59,10 @@ void ImagePlugin_LensDistortion::setEnabledActions(bool enable)
 
 void ImagePlugin_LensDistortion::slotLensDistortion()
 {
-    DigikamLensDistortionImagesPlugin::ImageEffect_LensDistortion dlg(parentWidget());
+    QString title = i18n("Lens Distortion Correction");
+    QFrame *headerFrame = new DigikamImagePlugins::BannerWidget(0, title);
+    DigikamLensDistortionImagesPlugin::ImageEffect_LensDistortion dlg(parentWidget(),
+            title, headerFrame);
     dlg.exec();
+    delete headerFrame;
 }
-
-
-#include "imageplugin_lensdistortion.moc"
