@@ -1,10 +1,9 @@
 /* ============================================================
- * File  : imageplugin_lensdistortion.h
- * Author: Gilles Caulier <caulier dot gilles at free.fr>
- * Date  : 2004-12-27
+ * Authors: Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Date   : 2004-12-27
  * Description : 
  * 
- * Copyright 2004-2005 by Gilles Caulier
+ * Copyright 2004-2007 by Gilles Caulier
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -19,7 +18,6 @@
  * 
  * ============================================================ */
 
-
 #ifndef IMAGEPLUGIN_LENSDISTORTION_H
 #define IMAGEPLUGIN_LENSDISTORTION_H
 
@@ -29,7 +27,7 @@
 
 class KAction;
 
-class ImagePlugin_LensDistortion : public Digikam::ImagePlugin
+class DIGIKAMIMAGEPLUGINS_EXPORT ImagePlugin_LensDistortion : public Digikam::ImagePlugin
 {
     Q_OBJECT
     
@@ -41,14 +39,13 @@ public:
 
     void setEnabledActions(bool enable);
 
-private:
-
-    KAction *m_lensdistortionAction;
-   
 private slots:
 
     void slotLensDistortion();
 
+private:
+
+    KAction *m_lensdistortionAction;
 };
     
 #endif /* IMAGEPLUGIN_LENSDISTORTION_H */
