@@ -1,10 +1,9 @@
 /* ============================================================
- * File  : imageplugin_oilpaint.cpp
- * Author: Gilles Caulier <caulier dot gilles at free.fr>
- * Date  : 2004-08-25
+ * Authors: Gilles Caulier
+ * Date   : 2004-08-25
  * Description : 
  * 
- * Copyright 2004 by Gilles Caulier
+ * Copyright 2004-2007 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -26,12 +25,13 @@
 #include <klibloader.h>
 #include <kaction.h>
 #include <kcursor.h>
-#include <kdebug.h>
 
 // Local includes.
 
+#include "bannerwidget.h"
 #include "imageeffect_oilpaint.h"
 #include "imageplugin_oilpaint.h"
+#include "imageplugin_oilpaint.moc"
 
 K_EXPORT_COMPONENT_FACTORY( digikamimageplugin_oilpaint,
                             KGenericFactory<ImagePlugin_OilPaint>("digikamimageplugin_oilpaint"));
@@ -40,24 +40,31 @@ ImagePlugin_OilPaint::ImagePlugin_OilPaint(QObject *parent, const char*,
                                                    const QStringList &)
                     : Digikam::ImagePlugin(parent, "ImagePlugin_OilPaint")
 {
-    new KAction(i18n("Oil Paint..."), "oilpaint", 0, 
-                this, SLOT(slotOilPaint()),
-                actionCollection(), "imageplugin_oilpaint");
+    m_oilpaintAction = new KAction(i18n("Oil Paint..."), "oilpaint", 0, 
+                       this, SLOT(slotOilPaint()),
+                       actionCollection(), "imageplugin_oilpaint");
                     
     setXMLFile( "digikamimageplugin_oilpaint_ui.rc" );          
     
-    kdDebug() << "ImagePlugin_OilPaint plugin loaded" << endl;
+    DDebug() << "ImagePlugin_OilPaint plugin loaded" << endl;
 }
 
 ImagePlugin_OilPaint::~ImagePlugin_OilPaint()
 {
 }
 
-void ImagePlugin_OilPaint::slotOilPaint()
+void ImagePlugin_OilPaint::setEnabledActions(bool enable)
 {
-    DigikamOilPaintImagesPlugin::ImageEffect_OilPaint dlg(parentWidget());
-    dlg.exec();
+    m_oilpaintAction->setEnabled(enable);
 }
 
+void ImagePlugin_OilPaint::slotOilPaint()
+{
+    QString title = i18n("Apply Oil Paint Effect");
+    QFrame *headerFrame = new DigikamImagePlugins::BannerWidget(0, title);
+    DigikamOilPaintImagesPlugin::ImageEffect_OilPaint dlg(parentWidget(),
+            title, headerFrame);
+    dlg.exec();
+    delete headerFrame;
+}
 
-#include "imageplugin_oilpaint.moc"
