@@ -1,11 +1,10 @@
 /* ============================================================
- * File  : imageeffect_perspective.h
- * Author: Gilles Caulier <caulier dot gilles at free.fr>
- * Date  : 2005-02-17
+ * Authors: Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Date   : 2005-02-17
  * Description : a digiKam image editor plugin for process image 
  *               perspective adjustment.
  * 
- * Copyright 2005 by Gilles Caulier
+ * Copyright 2005-2007 by Gilles Caulier
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -27,27 +26,42 @@
 
 #include <qrect.h>
 
-// Local includes.
+// Digikam includes.
 
-#include "imagedialogbase.h"
+#include <digikamheaders.h>
 
-class QPushButton;
 class QLabel;
+class QCheckBox;
+class QSpinBox;
+
+class KColorButton;
 
 namespace DigikamPerspectiveImagesPlugin
 {
 
 class PerspectiveWidget;
 
-class ImageEffect_Perspective : public DigikamImagePlugins::ImageDialogBase
+class ImageEffect_Perspective : public Digikam::ImageDlgBase
 {
     Q_OBJECT
 
 public:
 
-    ImageEffect_Perspective(QWidget* parent);
+    ImageEffect_Perspective(QWidget* parent, QString title, QFrame* banner);
     ~ImageEffect_Perspective();
 
+private slots:
+
+    void slotUpdateInfo(QRect newSize, float topLeftAngle, float topRightAngle,
+                        float bottomLeftAngle, float bottomRightAngle);
+
+private:
+
+    void readUserSettings();
+    void writeUserSettings();
+    void resetValues();
+    void finalRendering();
+
 private:
 
     QLabel            *m_newWidthLabel;
@@ -56,15 +70,15 @@ private:
     QLabel            *m_topRightAngleLabel;
     QLabel            *m_bottomLeftAngleLabel;
     QLabel            *m_bottomRightAngleLabel;
-    
-    PerspectiveWidget *m_previewWidget;
-                                                                    
-private slots:
 
-    void slotOk();
-    void slotDefault();
-    void slotUpdateInfo(QRect newSize, float topLeftAngle, float topRightAngle,
-                        float bottomLeftAngle, float bottomRightAngle);
+    QCheckBox         *m_drawWhileMovingCheckBox;
+    QCheckBox         *m_drawGridCheckBox;
+
+    QSpinBox          *m_guideSize;
+
+    KColorButton      *m_guideColorBt;
+
+    PerspectiveWidget *m_previewWidget;
 };
 
 }  // NameSpace DigikamPerspectiveImagesPlugin
