@@ -1,10 +1,9 @@
 /* ============================================================
- * File  : imageplugin_perspective.cpp
- * Author: Gilles Caulier <caulier dot gilles at free.fr>
- * Date  : 2005-02-17
+ * Authors: Gilles Caulier
+ * Date   : 2005-02-17
  * Description : 
  * 
- * Copyright 2005 by Gilles Caulier
+ * Copyright 2005-2007 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -26,12 +25,13 @@
 #include <klibloader.h>
 #include <kaction.h>
 #include <kcursor.h>
-#include <kdebug.h>
 
 // Local includes.
 
+#include "bannerwidget.h"
 #include "imageeffect_perspective.h"
 #include "imageplugin_perspective.h"
+#include "imageplugin_perspective.moc"
 
 K_EXPORT_COMPONENT_FACTORY( digikamimageplugin_perspective,
                             KGenericFactory<ImagePlugin_Perspective>("digikamimageplugin_perspective"));
@@ -45,7 +45,7 @@ ImagePlugin_Perspective::ImagePlugin_Perspective(QObject *parent, const char*, c
     
     setXMLFile("digikamimageplugin_perspective_ui.rc");      
                                     
-    kdDebug() << "ImagePlugin_Perspective plugin loaded" << endl;
+    DDebug() << "ImagePlugin_Perspective plugin loaded" << endl;
 }
 
 ImagePlugin_Perspective::~ImagePlugin_Perspective()
@@ -59,9 +59,11 @@ void ImagePlugin_Perspective::setEnabledActions(bool enable)
 
 void ImagePlugin_Perspective::slotPerspective()
 {
-    DigikamPerspectiveImagesPlugin::ImageEffect_Perspective dlg(parentWidget());
+    QString title = i18n("Adjust Photograph Perspective");
+    QFrame *headerFrame = new DigikamImagePlugins::BannerWidget(0, title);
+    DigikamPerspectiveImagesPlugin::ImageEffect_Perspective dlg(parentWidget(),
+                                    title, headerFrame);
     dlg.exec();
+    delete headerFrame;
 }
 
-
-#include "imageplugin_perspective.moc"
