@@ -1,10 +1,9 @@
 /* ============================================================
- * File  : imageplugin_perspective.h
- * Author: Gilles Caulier <caulier dot gilles at free.fr>
- * Date  : 2005-02-17
+ * Authors: Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Date   : 2005-02-17
  * Description : 
  * 
- * Copyright 2005 by Gilles Caulier
+ * Copyright 2005-2007 by Gilles Caulier
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -19,7 +18,6 @@
  * 
  * ============================================================ */
 
-
 #ifndef IMAGEPLUGIN_PERSPECTIVE_H
 #define IMAGEPLUGIN_PERSPECTIVE_H
 
@@ -27,7 +25,9 @@
 
 #include <digikamheaders.h>
 
-class ImagePlugin_Perspective : public Digikam::ImagePlugin
+class KAction;
+
+class DIGIKAMIMAGEPLUGINS_EXPORT ImagePlugin_Perspective : public Digikam::ImagePlugin
 {
     Q_OBJECT
     
@@ -37,10 +37,15 @@ public:
                          const QStringList &args);
     ~ImagePlugin_Perspective();
 
+    void setEnabledActions(bool enable);
+
 private slots:
 
     void slotPerspective();
 
+private:
+
+    KAction *m_perspectiveAction;
 };
     
 #endif /* IMAGEPLUGIN_PERSPECTIVE_H */
