@@ -1,11 +1,12 @@
 /* ============================================================
- * File  : imageeffect_raindrop.cpp
- * Author: Gilles Caulier <caulier dot gilles at free.fr>
- * Date  : 2004-09-30
+ * Authors: Gilles Caulier
+ *          Marcel Wiesweg <marcel dot wiesweg at gmx dot de>
+ * Date   : 2004-09-30
  * Description : a digiKam image plugin to add
  *               raindrops on an image.
  * 
- * Copyright 2004-2005 by Gilles Caulier
+ * Copyright 2004-2005 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright 2006-2007 by Gilles Caulier <caulier dot gilles at gmail dot com> and Marcel Wiesweg
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -30,51 +31,51 @@
 
 // KDE includes.
 
+#include <kconfig.h>
 #include <klocale.h>
 #include <kaboutdata.h>
 #include <kiconloader.h>
 #include <kapplication.h>
 #include <kstandarddirs.h>
 #include <knuminput.h>
-#include <kdebug.h>
-
-// Digikam includes.
-
-#include <digikamheaders.h>
 
 // Local includes.
 
 #include "version.h"
 #include "raindrop.h"
 #include "imageeffect_raindrop.h"
-
+#include "imageeffect_raindrop.moc"
 
 namespace DigikamRainDropImagesPlugin
 {
 
-ImageEffect_RainDrop::ImageEffect_RainDrop(QWidget* parent)
-                    : ImageGuideDialog(parent, i18n("Add Raindrops to Photograph"), "raindrops",
-                                       false, true, false)
+ImageEffect_RainDrop::ImageEffect_RainDrop(QWidget* parent, QString title, QFrame* banner)
+                    : Digikam::ImageGuideDlg(parent, title, "raindrops",
+                       false, true, false, Digikam::ImageGuideWidget::HVGuideMode, banner)
 {
     QString whatsThis;
-    
+
     KAboutData* about = new KAboutData("digikamimageplugins",
                                        I18N_NOOP("Raindrops"), 
                                        digikamimageplugins_version,
                                        I18N_NOOP("A digiKam image plugin to add raindrops to an image."),
                                        KAboutData::License_GPL,
-                                       "(c) 2004-2005, Gilles Caulier", 
+                                       "(c) 2004-2005, Gilles Caulier\n"
+                                       "(c) 2006-2007, Gilles Caulier and Marcel Wiesweg",
                                        0,
                                        "http://extragear.kde.org/apps/digikamimageplugins");
-                                       
+
     about->addAuthor("Gilles Caulier", I18N_NOOP("Author and maintainer"),
-                     "caulier dot gilles at free.fr");
+                     "caulier dot gilles at gmail dot com");
 
     about->addAuthor("Pieter Z. Voloshyn", I18N_NOOP("Raindrops algorithm"), 
-                     "pieter_voloshyn at ame.com.br"); 
-    
+                     "pieter dot voloshyn at gmail dot com"); 
+
+    about->addAuthor("Marcel Wiesweg", I18N_NOOP("Developer"),
+                     "marcel dot wiesweg at gmx dot de");
+
     setAboutData(about);
-    
+
     QWhatsThis::add( m_imagePreviewWidget, i18n("<p>This is the preview of the Raindrop effect."
                                            "<p>Note: if you have previously selected an area in the editor, "
                                            "this will be unaffected by the filter. You can use this method to "
@@ -145,6 +146,36 @@ void ImageEffect_RainDrop::renderingFinished()
     m_coeffInput->setEnabled(true);
 }
 
+void ImageEffect_RainDrop::readUserSettings(void)
+{
+    KConfig *config = kapp->config();
+    config->setGroup("raindrops Tool Dialog");
+
+    m_dropInput->blockSignals(true);
+    m_amountInput->blockSignals(true);
+    m_coeffInput->blockSignals(true);
+    
+    m_dropInput->setValue(config->readNumEntry("DropAdjustment", 80));
+    m_amountInput->setValue(config->readNumEntry("AmountAdjustment", 150));
+    m_coeffInput->setValue(config->readNumEntry("CoeffAdjustment", 30));
+    
+    m_dropInput->blockSignals(false);
+    m_amountInput->blockSignals(false);
+    m_coeffInput->blockSignals(false);
+    
+    slotEffect();
+}
+
+void ImageEffect_RainDrop::writeUserSettings(void)
+{
+    KConfig *config = kapp->config();
+    config->setGroup("raindrops Tool Dialog");
+    config->writeEntry("DropAdjustment", m_dropInput->value());
+    config->writeEntry("AmountAdjustment", m_amountInput->value());
+    config->writeEntry("CoeffAdjustment", m_coeffInput->value());
+    config->sync();
+}
+
 void ImageEffect_RainDrop::resetValues()
 {
     m_dropInput->blockSignals(true);
@@ -171,18 +202,14 @@ void ImageEffect_RainDrop::prepareEffect()
     int c        = m_coeffInput->value();
 
     Digikam::ImageIface* iface = m_imagePreviewWidget->imageIface();
-    QImage orgImage(iface->originalWidth(), iface->originalHeight(), 32);
-    uint *data = iface->getOriginalData();
-    memcpy( orgImage.bits(), data, orgImage.numBytes() );
-    
+
     // Selected data from the image
     QRect selection( iface->selectedXOrg(), iface->selectedYOrg(),
                      iface->selectedWidth(), iface->selectedHeight() );
-            
-    m_threadedFilter = dynamic_cast<Digikam::ThreadedFilter *>(
-                       new RainDrop(&orgImage, this, d, a, c, &selection));
-    delete [] data;
-}   
+
+    m_threadedFilter = dynamic_cast<Digikam::DImgThreadedFilter *>(
+                       new RainDrop(iface->getOriginalImg(), this, d, a, c, &selection));
+}
 
 void ImageEffect_RainDrop::prepareFinal()
 {
@@ -195,38 +222,33 @@ void ImageEffect_RainDrop::prepareFinal()
     int c       = m_coeffInput->value();
 
     Digikam::ImageIface iface(0, 0);
-    QImage orgImage(iface.originalWidth(), iface.originalHeight(), 32);
-    uint *data = iface.getOriginalData();
-    memcpy( orgImage.bits(), data, orgImage.numBytes() );
-    
+
     // Selected data from the image
     QRect selection( iface.selectedXOrg(), iface.selectedYOrg(),
                      iface.selectedWidth(), iface.selectedHeight() );
-                     
-    m_threadedFilter = dynamic_cast<Digikam::ThreadedFilter *>(
-                       new RainDrop(&orgImage, this, d, a, c, &selection));           
-    delete [] data;
+
+    m_threadedFilter = dynamic_cast<Digikam::DImgThreadedFilter *>(
+                       new RainDrop(iface.getOriginalImg(), this, d, a, c, &selection));
 }
 
 void ImageEffect_RainDrop::putPreviewData(void)
 {
     Digikam::ImageIface* iface = m_imagePreviewWidget->imageIface();
-                 
-    QImage imDest = m_threadedFilter->getTargetImage();
-    iface->putPreviewData((uint*)(imDest.smoothScale(iface->previewWidth(),
-                                                    iface->previewHeight())).bits());
 
-    m_imagePreviewWidget->updatePreview();    
+    Digikam::DImg imDest = m_threadedFilter->getTargetImage()
+            .smoothScale(iface->previewWidth(), iface->previewHeight());
+    iface->putPreviewImage(imDest.bits());
+
+    m_imagePreviewWidget->updatePreview();
 }
 
 void ImageEffect_RainDrop::putFinalData(void)
 {
-    Digikam::ImageIface iface(0, 0);    
-     
-    iface.putOriginalData(i18n("RainDrop"), 
-                         (uint*)m_threadedFilter->getTargetImage().bits());
+    Digikam::ImageIface iface(0, 0);
+
+    iface.putOriginalImage(i18n("RainDrop"),
+                           m_threadedFilter->getTargetImage().bits());
 }
 
 }  // NameSpace DigikamRainDropImagesPlugin
 
-#include "imageeffect_raindrop.moc"
