@@ -1,11 +1,11 @@
 /* ============================================================
  * File  : imageeffect_restoration.cpp
- * Author: Gilles Caulier <caulier dot gilles at free.fr>
+ * Author: Gilles Caulier <caulier dot gilles at gmail dot com>
  * Date  : 2005-03-26
  * Description : a digiKam image editor plugin to restore 
  *               a photograph
  * 
- * Copyright 2005 by Gilles Caulier
+ * Copyright 2005 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -45,11 +45,6 @@
 #include <kstandarddirs.h>
 #include <knuminput.h>
 #include <kmessagebox.h>
-#include <kdebug.h>
-
-// Digikam includes.
-
-#include <digikamheaders.h>
 
 // Local includes.
 
@@ -60,9 +55,9 @@
 namespace DigikamRestorationImagesPlugin
 {
 
-ImageEffect_Restoration::ImageEffect_Restoration(QWidget* parent)
-                       : CtrlPanelDialog(parent, i18n("Photograph Restoration"), 
-                                         "restoration", true, true)
+ImageEffect_Restoration::ImageEffect_Restoration(QWidget* parent, QString title, QFrame* banner)
+                       : Digikam::CtrlPanelDlg(parent, title, "restoration", true, true, true,
+                                               Digikam::ImagePannelWidget::SeparateViewAll, banner)
 {
     QString whatsThis;
 
@@ -78,7 +73,7 @@ ImageEffect_Restoration::ImageEffect_Restoration(QWidget* parent)
                                        "http://extragear.kde.org/apps/digikamimageplugins");
     
     about->addAuthor("Gilles Caulier", I18N_NOOP("Author and maintainer"),
-                     "caulier dot gilles at free.fr");
+                     "caulier dot gilles at gmail dot com");
                      
     about->addAuthor("David Tschumperle", I18N_NOOP("CImg library"), 0,
                      "http://cimg.sourceforge.net");
@@ -97,7 +92,7 @@ ImageEffect_Restoration::ImageEffect_Restoration(QWidget* parent)
     m_mainTab->addTab( firstPage, i18n("Preset") );
 
     KURLLabel *cimgLogoLabel = new KURLLabel(firstPage);
-    cimgLogoLabel->setText(QString::null);
+    cimgLogoLabel->setText(QString());
     cimgLogoLabel->setURL("http://cimg.sourceforge.net");
     KGlobal::dirs()->addResourceType("cimg-logo", KGlobal::dirs()->kde_default("data") + "digikamimageplugins/data");
     QString directory = KGlobal::dirs()->findResourceDir("cimg-logo", "cimg-logo.png");
@@ -112,9 +107,9 @@ ImageEffect_Restoration::ImageEffect_Restoration(QWidget* parent)
     m_restorationTypeCB->insertItem( i18n("Reduce Texturing") );
     QWhatsThis::add( m_restorationTypeCB, i18n("<p>Select here the filter preset to use for photograph restoration:<p>"
                                                "<b>None</b>: Most common values. Puts settings to default.<p>"
-                                               "<b>Reduce Uniform Noise</b>: reduce small image artefacts like sensor noise.<p>"
-                                               "<b>Reduce JPEG Artefacts</b>: reduce large image artefacts like JPEG compression mosaic.<p>"
-                                               "<b>Reduce Texturing</b>: reduce image artefacts like paper texture or Moire patterns "
+                                               "<b>Reduce Uniform Noise</b>: reduce small image artifacts like sensor noise.<p>"
+                                               "<b>Reduce JPEG Artefacts</b>: reduce large image artifacts like JPEG compression mosaic.<p>"
+                                               "<b>Reduce Texturing</b>: reduce image artifacts like paper texture or Moire patterns "
                                                "of a scanned image.<p>"));
 
     grid->addMultiCellWidget(cimgLogoLabel, 0, 0, 1, 1);
@@ -160,7 +155,7 @@ ImageEffect_Restoration::ImageEffect_Restoration(QWidget* parent)
     m_blurInput->setPrecision(2);
     m_blurInput->setRange(0.0, 10.0, 0.1, true);
     QWhatsThis::add( m_blurInput, i18n("<p>This value controls the smoothing regularity of the target image. "
-                                       "Do not use an high value here, or the "
+                                       "Do not use a high value here, or the "
                                        "target image will be completely blurred."));
     grid2->addMultiCellWidget(m_blurLabel, 3, 3, 0, 0);
     grid2->addMultiCellWidget(m_blurInput, 3, 3, 1, 1);
@@ -211,7 +206,7 @@ ImageEffect_Restoration::ImageEffect_Restoration(QWidget* parent)
     QWhatsThis::add( m_normalizeBox, i18n("<p>Enable this option to process an output image normalization."));
     grid3->addMultiCellWidget(m_normalizeBox, 4, 4, 0, 1);
     
-    m_imagePreviewWidget->setUserAreaWidget(m_mainTab, false);
+    m_imagePreviewWidget->setUserAreaWidget(m_mainTab);
     
     // -------------------------------------------------------------
     
@@ -277,31 +272,31 @@ void ImageEffect_Restoration::resetValues()
     m_normalizeBox->setChecked(false);
     
     switch(m_restorationTypeCB->currentItem())
-        {
+    {
         case ReduceUniformNoise:
-            {
+        {
             m_timeStepInput->setValue(40.0);
             break;
-            }
+        }
         
         case ReduceJPEGArtefacts:
-            {
+        {
             m_detailInput->setValue(0.3);
             m_blurInput->setValue(1.0);
             m_timeStepInput->setValue(100.0);
             m_blurItInput->setValue(2.0);
             break;
-            }
+        }
         
         case ReduceTexturing:
-            {
+        {
             m_detailInput->setValue(0.5);
             m_blurInput->setValue(1.5);
             m_timeStepInput->setValue(100.0);
             m_blurItInput->setValue(2.0);
             break;
-            }
-        }                       
+        }
+    }
                     
     m_detailInput->blockSignals(false);
     m_gradientInput->blockSignals(false);
@@ -334,9 +329,9 @@ void ImageEffect_Restoration::prepareEffect()
     m_linearInterpolationBox->setEnabled(false);
     m_normalizeBox->setEnabled(false);
     
-    QImage previewImage = m_imagePreviewWidget->getOriginalClipImage();
+    Digikam::DImg previewImage = m_imagePreviewWidget->getOriginalRegionImage();
     
-    m_threadedFilter = dynamic_cast<Digikam::ThreadedFilter *>(
+    m_threadedFilter = dynamic_cast<Digikam::DImgThreadedFilter *>(
                        new DigikamImagePlugins::CimgIface(&previewImage, 
                                     (uint)m_blurItInput->value(),
                                     m_timeStepInput->value(),
@@ -366,11 +361,11 @@ void ImageEffect_Restoration::prepareFinal()
     m_normalizeBox->setEnabled(false);
     
     Digikam::ImageIface iface(0, 0);
-    QImage originalImage(iface.originalWidth(), iface.originalHeight(), 32);
-    uint *data = iface.getOriginalData();
-    memcpy( originalImage.bits(), data, originalImage.numBytes() );
+    uchar *data = iface.getOriginalImage();
+    Digikam::DImg originalImage(iface.originalWidth(), iface.originalHeight(),
+                                iface.originalSixteenBit(), iface.originalHasAlpha(), data);
     
-    m_threadedFilter = dynamic_cast<Digikam::ThreadedFilter *>(
+    m_threadedFilter = dynamic_cast<Digikam::DImgThreadedFilter *>(
                        new DigikamImagePlugins::CimgIface(&originalImage, 
                                     (uint)m_blurItInput->value(),
                                     m_timeStepInput->value(),
@@ -388,16 +383,16 @@ void ImageEffect_Restoration::prepareFinal()
 
 void ImageEffect_Restoration::putPreviewData(void)
 {
-    QImage imDest = m_threadedFilter->getTargetImage();
-    m_imagePreviewWidget->setPreviewImageData(imDest);
+    Digikam::DImg imDest = m_threadedFilter->getTargetImage();
+    m_imagePreviewWidget->setPreviewImage(imDest);
 }
 
 void ImageEffect_Restoration::putFinalData(void)
 {
     Digikam::ImageIface iface(0, 0);
 
-    iface.putOriginalData(i18n("Restoration"), 
-                        (uint*)m_threadedFilter->getTargetImage().bits());
+    iface.putOriginalImage(i18n("Restoration"),
+                           m_threadedFilter->getTargetImage().bits());
 }
 
 void ImageEffect_Restoration::slotUser3()
@@ -411,16 +406,17 @@ void ImageEffect_Restoration::slotUser3()
     QFile file(loadRestorationFile.path());
     
     if ( file.open(IO_ReadOnly) )   
-        {
+    {
         QTextStream stream( &file );
+        
         if ( stream.readLine() != "# Photograph Restoration Configuration File" )
-           {
+        {
            KMessageBox::error(this, 
                         i18n("\"%1\" is not a Photograph Restoration settings text file.")
                         .arg(loadRestorationFile.fileName()));
            file.close();            
            return;
-           }
+        }
         
         blockSignals(true);
         m_normalizeBox->setChecked( stream.readLine().toInt() );
@@ -436,7 +432,7 @@ void ImageEffect_Restoration::slotUser3()
         m_gaussianInput->setValue( stream.readLine().toDouble() );
         blockSignals(false);
         slotEffect();  
-        }
+    }
     else
         KMessageBox::error(this, i18n("Cannot load settings from the Photograph Restoration text file."));
 
@@ -454,7 +450,7 @@ void ImageEffect_Restoration::slotUser2()
     QFile file(saveRestorationFile.path());
     
     if ( file.open(IO_WriteOnly) )   
-        {
+    {
         QTextStream stream( &file );        
         stream << "# Photograph Restoration Configuration File\n";    
         stream << m_normalizeBox->isChecked() << "\n";    
@@ -467,7 +463,7 @@ void ImageEffect_Restoration::slotUser2()
         stream << m_angularStepInput->value() << "\n";    
         stream << m_integralStepInput->value() << "\n";    
         stream << m_gaussianInput->value() << "\n";    
-        }
+    }
     else
         KMessageBox::error(this, i18n("Cannot save settings to the Photograph Restoration text file."));
     
