@@ -1,10 +1,9 @@
 /* ============================================================
- * File  : imageplugin_sheartool.cpp
- * Author: Gilles Caulier <caulier dot gilles at free.fr>
- * Date  : 2004-11-23
+ * Authors: Gilles Caulier
+ * Date   : 2004-11-23
  * Description : 
  * 
- * Copyright 2004-2005 by Gilles Caulier
+ * Copyright 2004-2007 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -26,12 +25,13 @@
 #include <klibloader.h>
 #include <kaction.h>
 #include <kcursor.h>
-#include <kdebug.h>
 
 // Local includes.
 
+#include "bannerwidget.h"
 #include "imageeffect_sheartool.h"
 #include "imageplugin_sheartool.h"
+#include "imageplugin_sheartool.moc"
 
 K_EXPORT_COMPONENT_FACTORY( digikamimageplugin_sheartool,
                             KGenericFactory<ImagePlugin_ShearTool>("digikamimageplugin_sheartool"));
@@ -45,7 +45,7 @@ ImagePlugin_ShearTool::ImagePlugin_ShearTool(QObject *parent, const char*, const
     
     setXMLFile("digikamimageplugin_sheartool_ui.rc");         
                                     
-    kdDebug() << "ImagePlugin_ShearTool plugin loaded" << endl;
+    DDebug() << "ImagePlugin_ShearTool plugin loaded" << endl;
 }
 
 ImagePlugin_ShearTool::~ImagePlugin_ShearTool()
@@ -59,9 +59,10 @@ void ImagePlugin_ShearTool::setEnabledActions(bool enable)
 
 void ImagePlugin_ShearTool::slotShearTool()
 {
-    DigikamShearToolImagesPlugin::ImageEffect_ShearTool dlg(parentWidget());
+    QString title = i18n("Shear Tool");
+    QFrame *headerFrame = new DigikamImagePlugins::BannerWidget(0, title);
+    DigikamShearToolImagesPlugin::ImageEffect_ShearTool dlg(parentWidget(),
+                                  title, headerFrame);
     dlg.exec();
+    delete headerFrame;    
 }
-
-
-#include "imageplugin_sheartool.moc"
