@@ -1,10 +1,9 @@
 /* ============================================================
- * File  : imageplugin_sheartool.h
- * Author: Gilles Caulier <caulier dot gilles at free.fr>
- * Date  : 2004-12-23
+ * Authors: Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Date   : 2004-12-23
  * Description : 
  * 
- * Copyright 2004 by Gilles Caulier
+ * Copyright 2004-2007 by Gilles Caulier
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -19,7 +18,6 @@
  * 
  * ============================================================ */
 
-
 #ifndef IMAGEPLUGIN_SHEARTOOL_H
 #define IMAGEPLUGIN_SHEARTOOL_H
 
@@ -27,7 +25,9 @@
 
 #include <digikamheaders.h>
 
-class ImagePlugin_ShearTool : public Digikam::ImagePlugin
+class KAction;
+
+class DIGIKAMIMAGEPLUGINS_EXPORT ImagePlugin_ShearTool : public Digikam::ImagePlugin
 {
     Q_OBJECT
     
@@ -37,10 +37,15 @@ public:
                          const QStringList &args);
     ~ImagePlugin_ShearTool();
 
+    void setEnabledActions(bool enable);
+
 private slots:
 
     void slotShearTool();
 
+private:
+
+    KAction *m_sheartoolAction;
 };
     
 #endif /* IMAGEPLUGIN_SHEARTOOL_H */
