@@ -1,10 +1,9 @@
 /* ============================================================
- * File   : dirselectwidet.cpp
- * Author: Gilles Caulier <caulier dot gilles at free.fr>
- * Date  : 2005-01-11
+ * Authors: Gilles Caulier
+ * Date   : 2005-01-11
  * Description : a directory selection widget.
  * 
- * Copyright 2005 by Gilles Caulier
+ * Copyright 2005-2007 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU Library General
@@ -28,12 +27,16 @@
 
 // KDE includes
 
-#include <kdebug.h>
 #include <klocale.h>
 
+// Digikam includes.
+
+#include <digikamheaders.h>
+
 // Local includes.
 
 #include "dirselectwidget.h"
+#include "dirselectwidget.moc"
 
 namespace DigikamSuperImposeImagesPlugin
 {
@@ -46,8 +49,21 @@ struct DirSelectWidget::Private
     KURL             m_rootUrl;
 };
 
-DirSelectWidget::DirSelectWidget( KURL rootUrl, KURL currentUrl, 
-                                  QWidget* parent, const char* name, QString headerLabel)
+DirSelectWidget::DirSelectWidget(QWidget* parent, const char* name, QString headerLabel)
+               : KFileTreeView( parent, name)
+{
+    d = new Private;
+    
+    addColumn( headerLabel );
+    
+    if ( headerLabel.isNull() )
+        header()->hide();
+        
+    setAlternateBackground(QColor::QColor());
+}
+
+DirSelectWidget::DirSelectWidget(KURL rootUrl, KURL currentUrl, 
+                                 QWidget* parent, const char* name, QString headerLabel)
                : KFileTreeView( parent, name)
 {
     d = new Private;
@@ -74,13 +90,13 @@ KURL DirSelectWidget::path() const
 void DirSelectWidget::load()
 {
     if ( d->m_pendingPath.isEmpty() ) 
-        {
+    {
         disconnect( d->m_item, SIGNAL( populateFinished(KFileTreeViewItem *) ), 
                     this, SLOT( load() ) );
         
         emit folderItemSelected(currentURL());
         return;
-        }
+    }
 
     QString item = d->m_pendingPath.front();
     d->m_pendingPath.pop_front();
@@ -88,19 +104,19 @@ void DirSelectWidget::load()
     KFileTreeViewItem* branch = findItem( d->m_item, d->m_handled );
     
     if ( !branch ) 
-        {
-        kdDebug() << "Unable to open " << d->m_handled << endl;
-        }
+    {
+        DDebug() << "Unable to open " << d->m_handled << endl;
+    }
     else
-        {
+    {
         branch->setOpen( true );
         setSelected( branch, true );
         ensureItemVisible ( branch );
-        d->m_handled += "/";
+        d->m_handled += '/';
         
         if ( branch->alreadyListed() )
             load();
-        }
+    }
 }
 
 void DirSelectWidget::setCurrentPath(KURL currentUrl)
@@ -111,7 +127,7 @@ void DirSelectWidget::setCurrentPath(KURL currentUrl)
     QString currentPath = QDir::cleanDirPath(currentUrl.path());
     currentPath = currentPath.mid( d->m_rootUrl.path().length() );
     d->m_pendingPath.clear();    
-    d->m_handled = QString::QString("");
+    d->m_handled = QString("");
     d->m_pendingPath = QStringList::split( "/", currentPath, true );
     
     if ( !d->m_pendingPath[0].isEmpty() )
@@ -162,4 +178,3 @@ void DirSelectWidget::slotFolderSelected(QListViewItem *)
 
 }   // NameSpace DigikamSuperImposeImagesPlugin
 
-#include "dirselectwidget.moc"
