@@ -1,10 +1,9 @@
 /* ============================================================
- * File  : imageplugin_superimpose.cpp
- * Author: Gilles Caulier <caulier dot gilles at free.fr>
- * Date  : 2005-01-04
+ * Authors: Gilles Caulier
+ * Date   : 2005-01-04
  * Description : 
  * 
- * Copyright 2005 by Gilles Caulier
+ * Copyright 2005-2007 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -26,12 +25,13 @@
 #include <klibloader.h>
 #include <kaction.h>
 #include <kcursor.h>
-#include <kdebug.h>
 
 // Local includes.
 
+#include "bannerwidget.h"
 #include "imageeffect_superimpose.h"
 #include "imageplugin_superimpose.h"
+#include "imageplugin_superimpose.moc"
 
 K_EXPORT_COMPONENT_FACTORY( digikamimageplugin_superimpose,
                             KGenericFactory<ImagePlugin_SuperImpose>("digikamimageplugin_superimpose"));
@@ -45,7 +45,7 @@ ImagePlugin_SuperImpose::ImagePlugin_SuperImpose(QObject *parent, const char*, c
 
     setXMLFile("digikamimageplugin_superimpose_ui.rc");        
                                     
-    kdDebug() << "ImagePlugin_SuperImpose plugin loaded" << endl;
+    DDebug() << "ImagePlugin_SuperImpose plugin loaded" << endl;
 }
 
 ImagePlugin_SuperImpose::~ImagePlugin_SuperImpose()
@@ -59,8 +59,11 @@ void ImagePlugin_SuperImpose::setEnabledActions(bool enable)
 
 void ImagePlugin_SuperImpose::slotSuperImpose()
 {
-    DigikamSuperImposeImagesPlugin::ImageEffect_SuperImpose dlg(parentWidget());
+    QString title = i18n("Template Superimpose to Photograph");
+    QFrame *headerFrame = new DigikamImagePlugins::BannerWidget(0, title);
+    DigikamSuperImposeImagesPlugin::ImageEffect_SuperImpose dlg(parentWidget(),
+                                    title, headerFrame);
     dlg.exec();
+    delete headerFrame;
 }
 
-#include "imageplugin_superimpose.moc"
