@@ -1,10 +1,9 @@
 /* ============================================================
- * File  : imageplugin_unsharp.h
- * Author: Gilles Caulier <caulier dot gilles at free.fr>
+ * Author: Gilles Caulier <caulier dot gilles at gmail dot com>
  * Date  : 2004-08-27
  * Description : 
  * 
- * Copyright 2004-2005 by Gilles Caulier
+ * Copyright 2004-2007 by Gilles Caulier
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -28,7 +27,7 @@
 
 class KAction;
 
-class ImagePlugin_Unsharp : public Digikam::ImagePlugin
+class DIGIKAMIMAGEPLUGINS_EXPORT ImagePlugin_Unsharp : public Digikam::ImagePlugin
 {
     Q_OBJECT
     
@@ -40,14 +39,13 @@ public:
 
     void setEnabledActions(bool enable);
 
-private:
-
-    KAction *m_unsharpAction;
-   
 private slots:
 
     void slotUnsharp();
 
+private:
+
+    KAction *m_unsharpAction;
 };
     
 #endif /* IMAGEPLUGIN_UNSHARP_H */
