@@ -1,10 +1,10 @@
 /* ============================================================
  * File  : unsharp.h
- * Author: Gilles Caulier <caulier dot gilles at free.fr>
+ * Author: Gilles Caulier <caulier dot gilles at gmail dot com>
  * Date  : 2005-05-25
  * Description : Unsharp Mask threaded image filter.
  * 
- * Copyright 2005 by Gilles Caulier
+ * Copyright 2005-2006 by Gilles Caulier
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -29,37 +29,27 @@
 namespace DigikamUnsharpMaskImagesPlugin
 {
 
-class UnsharpMask : public Digikam::ThreadedFilter
+class UnsharpMask : public Digikam::DImgThreadedFilter
 {
 
 public:
     
-    UnsharpMask(QImage *orgImage, QObject *parent=0, double radius=5.0, 
-                double amount=0.5, int threshold=0);
+    UnsharpMask(Digikam::DImg *orgImage, QObject *parent=0, int radius=1, 
+                double amount=1.0, double threshold=0.05);
     
     ~UnsharpMask(){};
     
 private:  // Unsharp Mask filter data.
 
-    double m_radius;
+    int    m_radius;
+
     double m_amount;
-    int    m_threshold;
+    double m_threshold;
     
 private:  // Unsharp Mask filter methods.
 
+   virtual void filterImage(void);
 
-    virtual void filterImage(void);
-    
-    void unsharpImage(uint* data, int w, int h, double radius, 
-                      double amount, int threshold);
-                 
-    inline void blur_line (double *ctable, double *cmatrix, int cmatrix_length,
-                           uchar *cur_col, uchar *dest_col, int y, long bytes);  
-                           
-    int gen_convolve_matrix (double radius, double **cmatrix_p);    
-    
-    double* gen_lookup_table (double *cmatrix, int cmatrix_length);
-    
 };    
 
 }  // NameSpace DigikamUnsharpMaskImagesPlugin
