@@ -1,14 +1,10 @@
 /* ============================================================
- * File  : imageeffect_whitebalance.cpp
- * Author: Gilles Caulier <caulier dot gilles at free.fr>
- * Date  : 2005-03-11
+ * Authors: Gilles Caulier
+ * Date   : 2005-03-11
  * Description : a digiKam image editor plugin to correct 
  *               image white balance 
  * 
- * Copyright 2005 by Gilles Caulier
- *
- * Some parts are inspired from RawPhoto implementation copyrighted 
- * 2004-2005 by Pawel T. Jochym <jochym at ifj edu pl>
+ * Copyright 2005-2007 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -23,18 +19,6 @@
  * 
  * ============================================================ */
 
-// Max input sample. 
-#define MAXSMPL 256 
-
-// Max output sample.
-#define MAXOUT 255
- 
-// C++ includes.
-
-#include <cstdio>
-#include <cmath>
-#include <cstring>
- 
 // Qt includes. 
  
 #include <qhgroupbox.h>
@@ -49,7 +33,6 @@
 #include <qtimer.h>
 #include <qtooltip.h>
 #include <qpixmap.h>
-#include <qcheckbox.h>
 #include <qfile.h>
 #include <qtextstream.h>
 
@@ -67,70 +50,62 @@
 #include <kmessagebox.h>
 #include <knuminput.h>
 #include <kglobalsettings.h>
-#include <kdebug.h>
 #include <kfiledialog.h>
 #include <kseparator.h>
-
-// Digikam includes.
-
-#include <digikamheaders.h>
+#include <kconfig.h>
 
 // Local includes.
 
 #include "version.h"
 #include "imageeffect_whitebalance.h"
-#include "blackbody.h"
+#include "imageeffect_whitebalance.moc"
 
 namespace DigikamWhiteBalanceImagesPlugin
 {
 
-ImageEffect_WhiteBalance::ImageEffect_WhiteBalance(QWidget* parent, uint *imageData, uint width, uint height)
-                        : ImageTabDialog(parent, i18n("White Color Balance Correction"), "whitebalance",
-                                         true, true, true)
+ImageEffect_WhiteBalance::ImageEffect_WhiteBalance(QWidget* parent, QString title, QFrame* banner)
+                        : Digikam::ImageDlgBase(parent, title, "whitebalance", true, false, banner)
 {
     QString whatsThis;
-    
-    m_originalImageData = imageData;
-    m_originalWidth     = width;
-    m_originalHeight    = height;
-    
-    m_clipSat = true;
-    
-    m_mr     = 1.0;
-    m_mg     = 1.0;
-    m_mb     = 1.0;
-    m_BP     = 0;
-    m_WP     = MAXSMPL;
-    m_rgbMax = 256;
-    
+
+    Digikam::ImageIface iface(0, 0);
+
     m_destinationPreviewData = 0L;
-    
+
     // About data and help button.
-    
+
     KAboutData* about = new KAboutData("digikamimageplugins",
                                        I18N_NOOP("White Color Balance Correction"), 
                                        digikamimageplugins_version,
                                        I18N_NOOP("A digiKam image plugin to correct white color balance."),
                                        KAboutData::License_GPL,
-                                       "(c) 2005, Gilles Caulier", 
+                                       "(c) 2005-2007, Gilles Caulier", 
                                        0,
                                        "http://extragear.kde.org/apps/digikamimageplugins");
-    
+
     about->addAuthor("Gilles Caulier", I18N_NOOP("Author and maintainer"),
-                     "caulier dot gilles at free.fr");
-    
+                     "caulier dot gilles at gmail dot com");
+
     about->addAuthor("Pawel T. Jochym", I18N_NOOP("White color balance correction algorithm"),
                      "jochym at ifj edu pl");
-    
+
     setAboutData(about);
-    
+
     // -------------------------------------------------------------
-    
+
+    m_previewWidget = new Digikam::ImageWidget("whitebalance Tool Dialog", plainPage(),
+                                               i18n("<p>You can see here the image's white-balance "
+                                                    "adjustments preview. You can pick color on image to "
+                                                    "see the color level corresponding on histogram."));
+    setPreviewAreaWidget(m_previewWidget); 
+
+    // -------------------------------------------------------------
+
     QWidget *gboxSettings = new QWidget(plainPage());
     QVBoxLayout* layout2 = new QVBoxLayout( gboxSettings, marginHint(), spacingHint() );
 
     QGridLayout *grid = new QGridLayout( layout2, 2, 4, spacingHint());
-    
+
     QLabel *label1 = new QLabel(i18n("Channel:"), gboxSettings);
     label1->setAlignment ( Qt::AlignRight | Qt::AlignVCenter );
     m_channelCB = new QComboBox( false, gboxSettings );
@@ -151,8 +126,9 @@ ImageEffect_WhiteBalance::ImageEffect_WhiteBalance(QWidget* parent, uint *imageD
     QWhatsThis::add( m_scaleBG, i18n("<p>Select here the histogram scale.<p>"
                                      "If the image's maximal counts are small, you can use the linear scale.<p>"
                                      "Logarithmic scale can be used when the maximal counts are big; "
-                                     "if it is used, all values (small and large) will be visible on the graph."));
-    
+                                     "if it is used, all values (small and large) will be visible on the "
+                                     "graph."));
+
     QPushButton *linHistoButton = new QPushButton( m_scaleBG );
     QToolTip::add( linHistoButton, i18n( "<p>Linear" ) );
     m_scaleBG->insert(linHistoButton, Digikam::HistogramWidget::LinScaleHistogram);
@@ -160,25 +136,24 @@ ImageEffect_WhiteBalance::ImageEffect_WhiteBalance(QWidget* parent, uint *imageD
     QString directory = KGlobal::dirs()->findResourceDir("histogram-lin", "histogram-lin.png");
     linHistoButton->setPixmap( QPixmap( directory + "histogram-lin.png" ) );
     linHistoButton->setToggleButton(true);
-    
+
     QPushButton *logHistoButton = new QPushButton( m_scaleBG );
     QToolTip::add( logHistoButton, i18n( "<p>Logarithmic" ) );
     m_scaleBG->insert(logHistoButton, Digikam::HistogramWidget::LogScaleHistogram);
     KGlobal::dirs()->addResourceType("histogram-log", KGlobal::dirs()->kde_default("data") + "digikam/data");
     directory = KGlobal::dirs()->findResourceDir("histogram-log", "histogram-log.png");
     logHistoButton->setPixmap( QPixmap( directory + "histogram-log.png" ) );
-    logHistoButton->setToggleButton(true);       
+    logHistoButton->setToggleButton(true);
 
     QHBoxLayout* l1 = new QHBoxLayout();
     l1->addWidget(label1);
     l1->addWidget(m_channelCB);
-    l1->addWidget(m_scaleBG);
     l1->addStretch(10);
-    
+    l1->addWidget(m_scaleBG);
+
     grid->addMultiCellLayout(l1, 0, 0, 0, 4);
-        
-    m_histogramWidget = new Digikam::HistogramWidget(256, 140, m_originalImageData, 
-                                                     m_originalWidth, m_originalHeight, 
+
+    m_histogramWidget = new Digikam::HistogramWidget(256, 140,
                                                      gboxSettings, false, true, true);
     QWhatsThis::add( m_histogramWidget, i18n("<p>Here you can see the target preview image histogram "
                                              "drawing of the selected image channel. This one is "
@@ -191,10 +166,10 @@ ImageEffect_WhiteBalance::ImageEffect_WhiteBalance(QWidget* parent, uint *imageD
     
     // -------------------------------------------------------------
 
-    QGridLayout *grid2 = new QGridLayout( layout2, 10, 5, spacingHint());
+    QGridLayout *grid2 = new QGridLayout( layout2, 9, 5, spacingHint());
     KIconLoader icon;
     
-    m_exposureLabel = new QLabel(i18n("Exposure:"), gboxSettings);
+    m_exposureLabel = new QLabel(i18n("Exposure (EV):"), gboxSettings);
     m_autoAdjustExposure = new QPushButton(gboxSettings);
     m_autoAdjustExposure->setPixmap( icon.loadIcon( "run", (KIcon::Group)KIcon::Toolbar ) );
     QToolTip::add( m_autoAdjustExposure, i18n( "Auto exposure adjustments" ) );
@@ -226,12 +201,12 @@ ImageEffect_WhiteBalance::ImageEffect_WhiteBalance(QWidget* parent, uint *imageD
     m_gammaLabel = new QLabel(i18n("Gamma:"), gboxSettings);
     m_gammaInput = new KDoubleNumInput(gboxSettings);
     m_gammaInput->setPrecision(2);
-    m_gammaInput->setRange(0.01, 1.5, 0.01, true);
+    m_gammaInput->setRange(0.1, 3.0, 0.01, true);
     QWhatsThis::add( m_gammaInput, i18n("<p>Set here the gamma correction value."));
 
     KSeparator *line = new KSeparator (Horizontal, gboxSettings);
             
-    m_temperatureLabel = new QLabel(i18n("Temperature:"), gboxSettings);
+    m_temperatureLabel = new QLabel(i18n("Temperature (K):"), gboxSettings);
     m_temperatureInput = new KDoubleNumInput(gboxSettings);
     m_temperatureInput->setPrecision(1);
     m_temperatureInput->setRange(2200.0, 7000.0, 10.0, true);
@@ -277,11 +252,6 @@ ImageEffect_WhiteBalance::ImageEffect_WhiteBalance(QWidget* parent, uint *imageD
     m_greenInput->setRange(1.0, 2.5, 0.01, true);
     QWhatsThis::add( m_greenInput, i18n("<p>Set here the green component to set magenta color cast removal level."));
 
-    m_overExposureIndicatorBox = new QCheckBox(i18n("Over exposure indicator"), gboxSettings);
-    QWhatsThis::add( m_overExposureIndicatorBox, i18n("<p>If you enable this option, over-exposed pixels "
-                                                      "from the target image preview will be over-colored. "
-                                                      "This will not have an effect on the final rendering."));
-                                                                  
     grid2->addMultiCellWidget(m_temperatureLabel, 0, 0, 0, 0);
     grid2->addMultiCellWidget(m_pickTemperature, 0, 0, 1, 1);
     grid2->addMultiCellWidget(m_temperatureInput, 0, 0, 2, 5);
@@ -303,28 +273,10 @@ ImageEffect_WhiteBalance::ImageEffect_WhiteBalance(QWidget* parent, uint *imageD
     grid2->addMultiCellWidget(m_exposureLabel, 8, 8, 0, 0);
     grid2->addMultiCellWidget(m_autoAdjustExposure, 8, 8, 1, 1);
     grid2->addMultiCellWidget(m_exposureInput, 8, 8, 2, 5);
-    grid2->addMultiCellWidget(m_overExposureIndicatorBox, 9, 9, 0, 5);
-
-    grid2->setRowStretch(10, 10);
+    grid2->setRowStretch(9, 10);
             
     setUserAreaWidget(gboxSettings);
             
-    // -------------------------------------------------------------
-    
-    m_previewOriginalWidget = previewOriginalWidget();
-    QWhatsThis::add( m_previewOriginalWidget, i18n("<p>You can see here the original image. You can pick "
-                                                   "color on image to select the tone to adjust image's "
-                                                   "white-balance with <b>Color Picker</b> method."));
-    m_previewTargetWidget   = previewTargetWidget();
-    QWhatsThis::add( m_previewTargetWidget, i18n("<p>You can see here the image's white-balance "
-                                                 "adjustments preview. You can pick color on image to "
-                                                 "see the color level corresponding on histogram."));
-    
-    // -------------------------------------------------------------
-    
-    // Reset all parameters to the default values.
-    QTimer::singleShot(0, this, SLOT(slotDefault()));
-
     // -------------------------------------------------------------
  
     connect(m_channelCB, SIGNAL(activated(int)),
@@ -333,19 +285,13 @@ ImageEffect_WhiteBalance::ImageEffect_WhiteBalance(QWidget* parent, uint *imageD
     connect(m_scaleBG, SIGNAL(released(int)),
             this, SLOT(slotScaleChanged(int)));
 
-    connect(m_previewOriginalWidget, SIGNAL(spotPositionChanged(  const QColor &, bool, const QPoint & )),
-            this, SLOT(slotColorSelectedFromOriginal( const QColor &, bool ))); 
+    connect(m_previewWidget, SIGNAL(spotPositionChangedFromOriginal( const Digikam::DColor &, const QPoint & )),
+            this, SLOT(slotColorSelectedFromOriginal( const Digikam::DColor & )));
 
-    connect(m_previewTargetWidget, SIGNAL(spotPositionChanged(  const QColor &, bool, const QPoint & )),
-            this, SLOT(slotColorSelectedFromTarget( const QColor & ))); 
-                        
-    connect(m_autoAdjustExposure, SIGNAL(clicked()),
-            this, SLOT(slotAutoAdjustExposure()));
-
-    connect(m_overExposureIndicatorBox, SIGNAL(toggled (bool)),
-            this, SLOT(slotEffect()));         
-
-    connect(m_previewTargetWidget, SIGNAL(signalResized()),
+    connect(m_previewWidget, SIGNAL(spotPositionChangedFromTarget( const Digikam::DColor &, const QPoint & )),
+            this, SLOT(slotColorSelectedFromTarget( const Digikam::DColor & )));
+                                    
+    connect(m_previewWidget, SIGNAL(signalResized()),
             this, SLOT(slotEffect()));                                        
 
     // -------------------------------------------------------------                
@@ -358,22 +304,31 @@ ImageEffect_WhiteBalance::ImageEffect_WhiteBalance(QWidget* parent, uint *imageD
             this, SLOT(slotTemperatureChanged(double)));                       
             
     connect(m_darkInput, SIGNAL(valueChanged (double)),
-            this, SLOT(slotEffect()));                       
+            this, SLOT(slotTimer()));                       
     
     connect(m_blackInput, SIGNAL(valueChanged (double)),
-            this, SLOT(slotEffect()));                       
+            this, SLOT(slotTimer()));                       
     
     connect(m_exposureInput, SIGNAL(valueChanged (double)),
-            this, SLOT(slotEffect()));                       
+            this, SLOT(slotTimer()));                       
     
     connect(m_gammaInput, SIGNAL(valueChanged (double)),
-            this, SLOT(slotEffect()));                       
+            this, SLOT(slotTimer()));                       
 
     connect(m_saturationInput, SIGNAL(valueChanged (double)),
-            this, SLOT(slotEffect()));                         
+            this, SLOT(slotTimer()));                         
 
     connect(m_greenInput, SIGNAL(valueChanged (double)),
-            this, SLOT(slotEffect()));                 
+            this, SLOT(slotTimer()));                 
+
+    // -------------------------------------------------------------
+    // Bouttons slots.
+    
+    connect(m_autoAdjustExposure, SIGNAL(clicked()),
+            this, SLOT(slotAutoAdjustExposure()));
+
+    connect(m_pickTemperature, SIGNAL(released()),
+            this, SLOT(slotPickerColorButtonActived()));            
 }
 
 ImageEffect_WhiteBalance::~ImageEffect_WhiteBalance()
@@ -386,60 +341,10 @@ ImageEffect_WhiteBalance::~ImageEffect_WhiteBalance()
     delete m_histogramWidget;
 }
 
-void ImageEffect_WhiteBalance::slotAutoAdjustExposure(void)
-{
-    parentWidget()->setCursor( KCursor::waitCursor() );
-
-    // Create an histogram of original image.     
-    
-    Digikam::ImageHistogram *histogram = new Digikam::ImageHistogram(m_originalImageData, 
-                                             m_originalWidth, m_originalHeight);
-       
-    // Calculate optimal exposition and black level 
-    
-    int stop, i, scale, w, h;
-    double black, expo, sum;
-    
-    w = m_originalWidth / 400;
-    h = m_originalHeight / 400;
-    scale = QMAX(w, h);
-    scale = QMAX(1, scale);
-    
-    // Cutoff at 0.5% of the histogram.
-    
-    stop = ((uint)(m_originalWidth / scale)*(uint)(m_originalHeight / scale)) / 200;
-    
-    for (i = m_rgbMax, sum = 0; (i >= 0) && (sum < stop); i--)
-        sum += histogram->getValue(Digikam::ImageHistogram::ValueChannel, i);
-    
-    expo = -log((float)(i+1) / m_rgbMax) / log(2);
-    kdDebug() << "White level at:" << i << endl;
-    
-    // Cutoff at 0.5% of the histogram. 
-    
-    stop = ((uint)(m_originalWidth / scale)*(uint)(m_originalHeight / scale)) / 200;
-    
-    for (i = 1, sum = 0; (i < 256) && (sum < stop); i++)
-        sum += histogram->getValue(Digikam::ImageHistogram::ValueChannel, i);
-    
-    black = (double)i / m_rgbMax;
-    black /= 2;
-    
-    kdDebug() << "Black:" << black << "  Exposition:" << expo << endl;
-
-    m_blackInput->setValue(black);
-    m_exposureInput->setValue(expo);        
-
-    delete histogram;
-    
-    parentWidget()->setCursor( KCursor::arrowCursor()  );
-    slotEffect();  
-}
-
 void ImageEffect_WhiteBalance::slotTemperatureChanged(double temperature)
 {
    switch((uint)temperature)
-       {
+   {
        case 2680:
           m_temperaturePresetCB->setCurrentItem(Lamp40W);
           break;
@@ -479,15 +384,15 @@ void ImageEffect_WhiteBalance::slotTemperatureChanged(double temperature)
        default:
           m_temperaturePresetCB->setCurrentItem(None);
           break;
-       }
+    }
 
-    slotEffect();  
+    slotTimer();  
 }
 
 void ImageEffect_WhiteBalance::slotTemperaturePresetChanged(int tempPreset)
 {
    switch(tempPreset)
-       {
+   {
        case Lamp40W:
           m_temperatureInput->setValue(2680.0);
           break;
@@ -526,61 +431,44 @@ void ImageEffect_WhiteBalance::slotTemperaturePresetChanged(int tempPreset)
        
        default:    // None.
           break;
-       }
+    }
 
     slotEffect();  
 }
 
-void ImageEffect_WhiteBalance::slotColorSelectedFromOriginal( const QColor &color, bool release )
+void ImageEffect_WhiteBalance::slotPickerColorButtonActived()
+{
+    // Save previous rendering mode and toggle to original image.
+    m_currentPreviewMode = m_previewWidget->getRenderingPreviewMode();
+    m_previewWidget->setRenderingPreviewMode(Digikam::ImageGuideWidget::PreviewOriginalImage);
+}
+
+void ImageEffect_WhiteBalance::slotColorSelectedFromOriginal(const Digikam::DColor &color)
 {
     if ( m_pickTemperature->isOn() )
-       {
-       // Calculate Temperature and Green component from color picked.
-              
-       register int l, r, m;
-       double sR, sG, sB, mRB, t;
+    {
+        Digikam::DColor dc = color;
+        QColor tc = dc.getQColor();
+        double temperatureLevel, greenLevel;
     
-       t   = QMAX( QMAX(color.red(), color.green()), color.blue());
-       sR  = color.red()   / t;
-       sG  = color.green() / t;
-       sB  = color.blue()  / t;
-       mRB = sR / sB;
-
-       kdDebug() << "Sums:  R:" << sR << " G:" << sG  << " B:" << sB << endl;
-    
-       l = 0;
-       r = sizeof(bbWB)/(sizeof(float)*3);
-       m = (r + l) / 2;
-    
-       for (l = 0, r = sizeof(bbWB)/(sizeof(float)*3), m = (l+r)/2 ; r-l > 1 ; m = (l+r)/2) 
-          {
-          if (bbWB[m][0]/bbWB[m][2] > mRB) 
-              l = m;
-          else
-              r = m;
-    
-          kdDebug() << "L,M,R:  " << l << " " << m << " " << r 
-                    << " bbWB[m]=:"    << bbWB[m][0]/bbWB[m][2]
-                    << endl;
-          }
+        Digikam::WhiteBalance::autoWBAdjustementFromColor(tc, temperatureLevel, greenLevel);
+            
+        m_temperatureInput->setValue(temperatureLevel);
+        m_greenInput->setValue(greenLevel);
+        m_pickTemperature->setOn(false);
+    }
+    else
+        return;
        
-       kdDebug() << "Temperature (K):" << m*10.0+2000.0 << endl;
-
-       t = (bbWB[m][1]/bbWB[m][0]) / (sG/sR);
+    // restore previous rendering mode.
+    m_previewWidget->setRenderingPreviewMode(m_currentPreviewMode);
     
-       kdDebug() << "Green component:" << t << endl;
-    
-       m_temperatureInput->setValue(m*10.0+2000.0);
-       m_greenInput->setValue(t);
-       m_pickTemperature->setOn(!release);
-       }
-
     slotEffect();  
 }
 
-void ImageEffect_WhiteBalance::slotColorSelectedFromTarget( const QColor &color )
+void ImageEffect_WhiteBalance::slotColorSelectedFromTarget( const Digikam::DColor &color )
 {
-    m_histogramWidget->setHistogramGuide(color);
+    m_histogramWidget->setHistogramGuideByColor(color);
 }
 
 void ImageEffect_WhiteBalance::slotScaleChanged(int scale)
@@ -592,7 +480,7 @@ void ImageEffect_WhiteBalance::slotScaleChanged(int scale)
 void ImageEffect_WhiteBalance::slotChannelChanged(int channel)
 {
     switch(channel)
-       {
+    {
        case LuminosityChannel:
           m_histogramWidget->m_channelType = Digikam::HistogramWidget::ValueHistogram;
           m_hGradient->setColors( QColor( "black" ), QColor( "white" ) );
@@ -612,191 +500,103 @@ void ImageEffect_WhiteBalance::slotChannelChanged(int channel)
           m_histogramWidget->m_channelType = Digikam::HistogramWidget::BlueChannelHistogram;
           m_hGradient->setColors( QColor( "black" ), QColor( "blue" ) );
           break;
-       }
+    }
 
     m_histogramWidget->repaint(false);
 }
 
+void ImageEffect_WhiteBalance::slotAutoAdjustExposure()
+{
+    parentWidget()->setCursor( KCursor::waitCursor() );
+
+    Digikam::ImageIface* iface = m_previewWidget->imageIface();
+    uchar *data                = iface->getOriginalImage();
+    int width                  = iface->originalWidth();
+    int height                 = iface->originalHeight();
+    bool sb                    = iface->originalSixteenBit();
+    
+    double blackLevel;
+    double exposureLevel;
+
+    Digikam::WhiteBalance::autoExposureAdjustement(data, width, height, sb, blackLevel, exposureLevel);
+    delete [] data;        
+
+    m_blackInput->setValue(blackLevel);
+    m_exposureInput->setValue(exposureLevel);
+    
+    parentWidget()->unsetCursor();
+    slotEffect();  
+}
+
 void ImageEffect_WhiteBalance::slotEffect()
 {
-    Digikam::ImageIface* ifaceDest = m_previewTargetWidget->imageIface();
-
-    uint*  data   = ifaceDest->getPreviewData();
-    int    w      = ifaceDest->previewWidth();
-    int    h      = ifaceDest->previewHeight();
+    Digikam::ImageIface* iface = m_previewWidget->imageIface();
+    uchar *data                = iface->getPreviewImage();
+    int w                      = iface->previewWidth();
+    int h                      = iface->previewHeight();
+    bool sb                    = iface->previewSixteenBit();
     
     // Create the new empty destination image data space.
     m_histogramWidget->stopHistogramComputation();
 
     if (m_destinationPreviewData) 
        delete [] m_destinationPreviewData;
-    
-    m_destinationPreviewData = new uint[w*h];
-    memcpy (m_destinationPreviewData, data, w*h*4);  
-    
-    // Update settings
-    m_temperature = m_temperatureInput->value()/1000.0;
-    m_dark        = m_darkInput->value();
-    m_black       = m_blackInput->value();
-    m_exposition  = m_exposureInput->value();
-    m_gamma       = 2.0-m_gammaInput->value();
-    m_saturation  = m_saturationInput->value();
-    m_green       = m_greenInput->value();
-    m_overExp     = m_overExposureIndicatorBox->isChecked();
-    m_WBind       = m_overExp;
-    
-    // Set preview lut.
-    setRGBmult();
-    m_mg = 1.0;
-    setLUTv();
-    setRGBmult();
-       
-    // Apply White balance adjustments.
-    whiteBalance(m_destinationPreviewData, w, h);
-           
-    ifaceDest->putPreviewData(m_destinationPreviewData);       
-    m_previewTargetWidget->updatePreview();
+
+    m_destinationPreviewData = new uchar[w*h*(sb ? 8 : 4)];
+
+    double temperature = m_temperatureInput->value()/1000.0;
+    double dark        = m_darkInput->value();
+    double black       = m_blackInput->value();
+    double exposition  = m_exposureInput->value();
+    double gamma       = 2.0-m_gammaInput->value();
+    double saturation  = m_saturationInput->value();
+    double green       = m_greenInput->value();
+            
+    Digikam::WhiteBalance wbFilter(sb);
+    wbFilter.whiteBalance(data, w, h, sb, 
+                          black, exposition,
+                          temperature, green, dark, 
+                          gamma, saturation);
+     
+    iface->putPreviewImage(data);
+    m_previewWidget->updatePreview();
     
     // Update histogram.
-    m_histogramWidget->updateData(m_destinationPreviewData, w, h, 0, 0, 0, false); 
-    
+    memcpy (m_destinationPreviewData, data, w*h*(sb ? 8 : 4));
+    m_histogramWidget->updateData(m_destinationPreviewData, w, h, sb, 0, 0, 0, false);
     delete [] data;
 }
 
-void ImageEffect_WhiteBalance::slotOk()
+void ImageEffect_WhiteBalance::finalRendering()
 {
     kapp->setOverrideCursor( KCursor::waitCursor() );
-    Digikam::ImageIface ifaceDest(0, 0);
-        
-    uint*  data   = ifaceDest.getOriginalData();
-    int    w      = ifaceDest.originalWidth();
-    int    h      = ifaceDest.originalHeight();
-        
-    // Update settings
-    m_temperature = m_temperatureInput->value()/1000.0;
-    m_dark        = m_darkInput->value();
-    m_black       = m_blackInput->value();
-    m_exposition  = m_exposureInput->value();
-    m_gamma       = 2.0-m_gammaInput->value();
-    m_saturation  = m_saturationInput->value();
-    m_green       = m_greenInput->value();
-    m_overExp     = false;
-    m_WBind       = false;
-       
-    // Set final lut.
-    setRGBmult();
-    m_mr = m_mb = 1.0;
-    if (m_clipSat) m_mg = 1.0; 
-    setLUTv();
-    setRGBmult();
-       
-    // Apply White balance adjustments.
-    whiteBalance(data, w, h);
+    Digikam::ImageIface* iface = m_previewWidget->imageIface();
+    uchar *data                = iface->getOriginalImage();
+    int w                      = iface->originalWidth();
+    int h                      = iface->originalHeight();
+    bool sb                    = iface->originalSixteenBit();
 
-    ifaceDest.putOriginalData(i18n("White Balance"), data);                   
+    double temperature = m_temperatureInput->value()/1000.0;
+    double dark        = m_darkInput->value();
+    double black       = m_blackInput->value();
+    double exposition  = m_exposureInput->value();
+    double gamma       = 2.0-m_gammaInput->value();
+    double saturation  = m_saturationInput->value();
+    double green       = m_greenInput->value();
+            
+    Digikam::WhiteBalance wbFilter(sb);
+    wbFilter.whiteBalance(data, w, h, sb, 
+                          black, exposition,
+                          temperature, green, dark, 
+                          gamma, saturation);
+
+    iface->putOriginalImage(i18n("White Balance"), data);
     delete [] data;
     kapp->restoreOverrideCursor();
     accept();       
 }
 
-void ImageEffect_WhiteBalance::setRGBmult(void)
-{
-    int   t;
-    float mi;
-
-    if ( m_temperature > 7.0 ) m_temperature = 7.0;
-    
-    t     = (int)(m_temperature * 100.0 - 200.0);
-    m_mr  = 1.0 / bbWB[t][0];
-    m_mg  = 1.0 / bbWB[t][1];
-    m_mb  = 1.0 / bbWB[t][2];
-    m_mg *= m_green;
-    
-    // Normalize to at least 1.0, so we are not dimming colors only bumping.
-    mi    = QMIN(m_mr, m_mg);
-    mi    = QMIN(mi, m_mb);
-    m_mr /= mi;
-    m_mg /= mi;
-    m_mb /= mi;
-}
-
-void ImageEffect_WhiteBalance::setLUTv(void)
-{
-    double b, g;
-
-    b    = m_mg * pow(2, m_exposition);
-    g    = m_gamma;
-    m_BP = (uint)(m_rgbMax * m_black);
-    m_WP = (uint)(m_rgbMax / b);
-    
-    if (m_WP - m_BP < 1) m_WP = m_BP + 1;
-
-    kdDebug() << "T(K): " << m_temperature
-              << " => R:" << m_mr
-              << " G:"    << m_mg
-              << " B:"    << m_mb
-              << " BP:"   << m_BP
-              << " WP:"   << m_WP
-              << endl;
-    
-    m_curve[0] = 0;
-    
-    for (int i = 1; i < 256; i++)
-        {
-        float x = (float)(i - m_BP)/(m_WP - m_BP);
-        m_curve[i]  = (i < m_BP) ? 0 : MAXOUT * pow(x, g);
-        m_curve[i] *= (1 - m_dark * exp(-x * x / 0.002));
-        m_curve[i] /= (float)i;
-        }
-}
-
-void ImageEffect_WhiteBalance::whiteBalance(uint *data, int width, int height)
-{  
-    int  x, y;
-    uint i, j=0;
-    Digikam::ImageFilters::imageData imagedata;
-         
-    for (y = 0 ; y < height ; y++)
-        {
-        for (x = 0 ; x < width ; x++, j++) 
-            {
-            int v, rv[3];
-
-            imagedata.raw = data[j];
-            rv[0] = (int)(imagedata.channel.blue  * m_mb);
-            rv[1] = (int)(imagedata.channel.green * m_mg);
-            rv[2] = (int)(imagedata.channel.red   * m_mr);
-            v = QMAX(rv[0], rv[1]);
-            v = QMAX(v, rv[2]); 
-            
-            if (m_clipSat) v = QMIN(v, (int)m_rgbMax-1);
-            i = v;
-
-            imagedata.channel.blue  = pixelColor(rv[0], i, v);
-            imagedata.channel.green = pixelColor(rv[1], i, v);
-            imagedata.channel.red   = pixelColor(rv[2], i, v);
-            data[j]                 = imagedata.raw;
-            }
-        }
-}
-
-uchar ImageEffect_WhiteBalance::pixelColor(int colorMult, int index, int value)
-{
-    int r = (m_clipSat && colorMult > (int)m_rgbMax) ? m_rgbMax : colorMult;
-
-    if (value > m_BP && m_overExp && value > m_WP) 
-        {
-        if (m_WBind) 
-           r = (colorMult > m_WP) ? 0 : r;
-        else 
-           r = 0;
-        }
-    
-    return( (uchar)CLAMP((int)((index - m_saturation*(index - r)) * m_curve[index]), 0, MAXOUT) );
-}               
-
-// Reset all settings.
-void ImageEffect_WhiteBalance::slotDefault()
+void ImageEffect_WhiteBalance::resetValues()
 {
     m_darkInput->blockSignals(true);
     m_blackInput->blockSignals(true);
@@ -816,7 +616,7 @@ void ImageEffect_WhiteBalance::slotDefault()
     m_temperaturePresetCB->setCurrentItem(Neutral);
     slotTemperaturePresetChanged(Neutral);
     
-    m_previewOriginalWidget->resetSpotPosition();    
+    m_previewWidget->resetSpotPosition();    
     m_channelCB->setCurrentItem(LuminosityChannel);
     slotChannelChanged(LuminosityChannel);
     
@@ -832,6 +632,42 @@ void ImageEffect_WhiteBalance::slotDefault()
     slotEffect();  
 } 
 
+void ImageEffect_WhiteBalance::readUserSettings()
+{
+    KConfig* config = kapp->config();
+    config->setGroup("whitebalance Tool Dialog");
+    m_channelCB->setCurrentItem(config->readNumEntry("Histogram Channel", 0));    // Luminosity.
+    m_scaleBG->setButton(config->readNumEntry("Histogram Scale", Digikam::HistogramWidget::LogScaleHistogram));
+
+    m_darkInput->setValue(config->readDoubleNumEntry("Dark", 0.5));
+    m_blackInput->setValue(config->readDoubleNumEntry("Black", 0.0));
+    m_exposureInput->setValue(config->readDoubleNumEntry("Exposure", 0.0));
+    m_gammaInput->setValue(config->readDoubleNumEntry("Gamma", 1.0));  
+    m_saturationInput->setValue(config->readDoubleNumEntry("Saturation", 1.0));  
+    m_greenInput->setValue(config->readDoubleNumEntry("Green", 1.2));  
+    m_temperatureInput->setValue(config->readDoubleNumEntry("Temperature", 4750.0));
+    slotTemperatureChanged(m_temperatureInput->value());
+    slotChannelChanged(m_channelCB->currentItem());
+    slotScaleChanged(m_scaleBG->selectedId());
+}
+
+void ImageEffect_WhiteBalance::writeUserSettings()
+{
+    KConfig* config = kapp->config();
+    config->setGroup("whitebalance Tool Dialog");
+    config->writeEntry("Histogram Channel", m_channelCB->currentItem());
+    config->writeEntry("Histogram Scale", m_scaleBG->selectedId());
+
+    config->writeEntry("Dark", m_darkInput->value());
+    config->writeEntry("Black", m_blackInput->value());
+    config->writeEntry("Exposure", m_exposureInput->value());
+    config->writeEntry("Gamma", m_gammaInput->value());
+    config->writeEntry("Saturation", m_saturationInput->value());
+    config->writeEntry("Green", m_greenInput->value());
+    config->writeEntry("Temperature", m_temperatureInput->value()); 
+    config->sync();
+}
+
 // Load all settings.
 void ImageEffect_WhiteBalance::slotUser3()
 {
@@ -844,16 +680,17 @@ void ImageEffect_WhiteBalance::slotUser3()
     QFile file(loadWhiteBalanceFile.path());
     
     if ( file.open(IO_ReadOnly) )   
-        {
+    {
         QTextStream stream( &file );
+
         if ( stream.readLine() != "# White Color Balance Configuration File" )
-           {
+        {
            KMessageBox::error(this, 
                         i18n("\"%1\" is not a White Color Balance settings text file.")
                         .arg(loadWhiteBalanceFile.fileName()));
            file.close();            
            return;
-           }
+        }
         
         blockSignals(true);
         m_temperatureInput->setValue( stream.readLine().toDouble() );
@@ -866,7 +703,7 @@ void ImageEffect_WhiteBalance::slotUser3()
         m_histogramWidget->reset();
         blockSignals(false);
         slotEffect();  
-        }
+    }
     else
         KMessageBox::error(this, i18n("Cannot load settings from the White Color Balance text file."));
 
@@ -885,7 +722,7 @@ void ImageEffect_WhiteBalance::slotUser2()
     QFile file(saveWhiteBalanceFile.path());
     
     if ( file.open(IO_WriteOnly) )   
-        {
+    {
         QTextStream stream( &file );        
         stream << "# White Color Balance Configuration File\n";    
         stream << m_temperatureInput->value() << "\n";    
@@ -895,7 +732,7 @@ void ImageEffect_WhiteBalance::slotUser2()
         stream << m_gammaInput->value() << "\n";    
         stream << m_saturationInput->value() << "\n";    
         stream << m_greenInput->value() << "\n";    
-        }
+    }
     else
         KMessageBox::error(this, i18n("Cannot save settings to the White Color Balance text file."));
     
@@ -904,4 +741,3 @@ void ImageEffect_WhiteBalance::slotUser2()
 
 }  // NameSpace DigikamWhiteBalanceImagesPlugin
 
-#include "imageeffect_whitebalance.moc"
