@@ -1,7 +1,6 @@
 /* ============================================================
- * File  : imageplugin_whitebalance.h
- * Author: Gilles Caulier <caulier dot gilles at free.fr>
- * Date  : 2005-03-11
+ * Authors: Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Date   : 2005-03-11
  * Description : 
  * 
  * Copyright 2005 by Gilles Caulier
@@ -29,7 +28,7 @@
 
 class KAction;
 
-class ImagePlugin_WhiteBalance : public Digikam::ImagePlugin
+class DIGIKAMIMAGEPLUGINS_EXPORT ImagePlugin_WhiteBalance : public Digikam::ImagePlugin
 {
     Q_OBJECT
     
